import os
import time

import oss2
import requests
import xlrd
import xlwt
from dateutil.relativedelta import relativedelta
from flask import current_app, jsonify, request
from sqlalchemy import and_
import zipfile

from apps.models import *

from apps.models import ProjectManagement
from apps.utils.response_code import RET
from apps.inves_manage import api_manage
from apps.util import verify_token


# 项目管理---项目列表
from apps.inves_manage.view import get_num


# 获取项目列表
@api_manage.route("/SearchProject1", methods=["POST"])
def search_project1():
    req_dic = request.get_json()

    token = request.headers['token']

    project_stalker = req_dic['project_stalker']

    project_name = req_dic['project_name']
    district = req_dic['district']
    development_area = req_dic['development_area']
    investor_name = req_dic['investor_name']
    investor_district = req_dic['investor_district']
    industry = req_dic['industry']
    investment_volume = req_dic['investment_volume']
    project_progress = req_dic['project_progress']
    project_year = req_dic['project_year']
    page = req_dic['page']
    per_page = req_dic['per_page']

    try:
        user_obj = verify_token(token)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")

    try:
        project_obj = ProjectManagement.query.filter(
            and_(ProjectManagement.project_name.like('%{}%'.format(project_name)) if project_name else text(''),
                 ProjectManagement.project_stalker == project_stalker if project_stalker else text(''),
                 ProjectManagement.project_name == project_name if project_name else text(''),
                 ProjectManagement.district == district if district else text(''),
                 ProjectManagement.development_area == development_area if development_area else text(''),
                 ProjectManagement.investor_name >= investor_name[0] if investor_name else text(''),
                 ProjectManagement.investor_name < investor_name[1] if investor_name else text(''),
                 ProjectManagement.investor_district == investor_district if investor_district else text(''),
                 ProjectManagement.industry == industry if industry else text(''),
                 ProjectManagement.investment_volume == investment_volume if investment_volume else text(''),
                 ProjectManagement.project_progress == project_progress if project_progress else text(''),
                 ProjectManagement.project_year == project_year if project_year else text(''),
                 ))

        if not project_obj.all():
            return jsonify(code=RET.NODATA, msg='没有符合条件的数据！')
        project_size = project_obj.count()

        project_obj_list = project_obj.order_by(ProjectManagement.file_time.desc()).paginate(page, per_page).items
        if project_obj_list:
            data = [{
                "id": project_obj.id,
                "project_stalker": project_obj.project_stalker,
                "project_name": project_obj.project_name,
                "district": project_obj.district,
                "development_area": project_obj.development_area,
                "attract_name": project_obj.attract_name,
                "investor_name": project_obj.investor_name,
                "investor_district": project_obj.investor_district,
                "industry": project_obj.industry,
                "investment_volume": project_obj.investment_volume,
                "construction_content": project_obj.construction_content,
                "project_address": project_obj.project_address,
                "project_progress": project_obj.project_progress,
                "project_problem": project_obj.project_problem,
                "project_year": project_obj.project_year
            } for project_obj in project_obj_list]
            return jsonify(code=RET.OK, data={"data": data, "size": project_size, "msg": "数据获取成功！"})

    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="查询数据库错误！")


# 项目详情
@api_manage.route("/CheckProjectDetail1", methods=["POST"])
def check_project_detail1():
    req_dic = request.get_json()
    project_id = req_dic['project_id']
    token = request.headers['token']
    try:
        user_obj = verify_token(token)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")
    if not project_id:
        return jsonify(code=RET.PARAMERR, msg="参数不能为空！")
    try:
        project_obj_list = ProjectManagement.query.filter_by(id=project_id)
        data = [{"id": project_obj.id,
                 "project_stalker": project_obj.project_stalker,  # 项目跟踪
                 "project_name": project_obj.project_name,  # 项目名称
                 "district": project_obj.district,  # 项目所在地
                 "development_area": project_obj.development_area,  # 开发区
                 "attract_name": project_obj.attract_name,  # 引资方名称
                 "investor_name": project_obj.investor_name,  # 投资方名称(万元)
                 "investor_district": project_obj.investor_district,  # 投资方所在地(亩)
                 "industry": project_obj.industry,  # 所属行业
                 "investment_volume": project_obj.investment_volume,  # 总投资额(万元)
                 "construction_content": project_obj.construction_content,  # 建设内容
                 "project_address": project_obj.project_address,  # 项目选址
                 "project_progress": project_obj.project_progress,  # 项目进展
                 "project_problem": project_obj.project_problem,  # 难点情况
                 "project_year": project_obj.project_year,  # 项目年份
                 "upload_unity": project_obj.upload_unity,  # 上传部门
                 "upload_people": project_obj.upload_people,  # 上传人
                 "upload_time": project_obj.upload_time,  # 上传时间
                 "project_num": project_obj.project_num,  # 项目编号
                 "project_source": project_obj.project_source,  # 项目来源
                 "project_unity": project_obj.project_unity,  # 项目申报单位
                 "is_development_project": project_obj.is_development_project,  # 是否属于开发区项目
                 "sign_time": project_obj.sign_time,  # 签约时间
                 "start_time": project_obj.start_time,  # 开工时间
                 "end_time": project_obj.end_time,  # 竣工时间
                 "investor_rank": project_obj.investor_rank,  # 投资方排名
                 "is_transf_project": project_obj.is_transf_project,  # 是否转型项目
                 "country": project_obj.country,  # 投资方国别
                 "provence": project_obj.provence,  # 投资方省份
                 "city": project_obj.city,  # 投资方市
                 "job_num": project_obj.job_num,  # 带动就业岗位（个）
                 "new_value": project_obj.new_value,  # 新增产值（亿元）
                 "revenue": project_obj.revenue,  # 贡献税收（亿元）
                 "use_land": project_obj.use_land,  # 项目用地情况（亩）
                 "new_land": project_obj.new_land,  # 其中新增用地（亩）
                 "construction_nature": project_obj.construction_nature,  # 建设性质（亩）
                 "is_fixed_investment": project_obj.is_fixed_investment,  # 固定资产投资项目
                 "investment_year": project_obj.investment_year,  # 资金到位本年累计（万元）
                 "investment_history": project_obj.investment_history,  # 资金到位历史累计（万元）
                 "cooperation_way": project_obj.cooperation_way,  # 合作方式
                 "set_project_status": project_obj.set_project_status,  # 项目立项状态
                 "investor_people": project_obj.investor_people,  # 投资方联系人
                 "investor_mobile": project_obj.investor_mobile,  # 投资方电话
                 "investor_address": project_obj.investor_address,  # 投资方联系地址
                 } for project_obj in project_obj_list]
        return jsonify(code=RET.OK, data={"data": data, "msg": "数据获取成功！"})
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="操作失败！数据库查询错误")


# 下载模板
@api_manage.route("/DownloadProjectTemplate", methods=["POST"])
def download_project_template():
    token = request.headers['token']
    try:
        user_obj = verify_token(token)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")
    project_template = "http://39.100.39.50:8008/aaa_statics/招商引资项目表.xlsx"
    return jsonify(code=RET.OK, data=project_template, msg="模板下载成功！")


# 批量导入
@api_manage.route("/UploadProjectData2", methods=["POST"])
def upload_project_data2():
    # 获取上传的文件
    token = request.headers['token']
    action_name = '批量导入'

    token = request.headers['token']
    try:
        user_obj = verify_token(token)
        user_name = user_obj.real_name
        user_unity = user_obj.belong_organization
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")
    # 上传的文件
    file = request.files['file']
    print(file.filename)  # 打印文件名

    try:
        f = file.read()  # 文件内容
        data = xlrd.open_workbook(file_contents=f)
        table = data.sheets()[0]
        names = data.sheet_names()  # 返回book中所有工作表的名字
        status = data.sheet_loaded(names[0])  # 检查sheet1是否导入完毕
        print(status)
        nrows = table.nrows  # 获取该sheet中的有效行数
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.THIRDERR, msg="读取文件失败！")

    rep_num = 0
    rep_project_name_list = []
    success_num = 0
    name = ''

    row_list = [table.row_values(i) for i in range(4, nrows)]
    for i in range(0, len(row_list)):
        row_content = row_list[i]
        if not row_content:
            return jsonify(code=RET.NODATA,
                           msg="表格内无有效数据！请尝试 <清空浏览器缓存> 后下载最新模板，根据模板提示信息编辑数据后再次上传。(注：第三行为首行有效数据不能为空、第一行和第二行无法读取。)")
        # del (row_content[0])
        project_name = row_content[1]  # 项目名称
        # 判断该项目是否已经存在
        project_obj = ProjectManagement.query.filter_by(project_name=project_name).first()
        if project_obj:
            rep_num += 1
            rep_project_name_list.append(project_name)
            continue
        try:
            project_name = row_content[1]  # 项目名称
            district = row_content[2]  # 项目所在地
            development_area = row_content[3]  # 开发区
            attract_name = row_content[4]  # 引资方名称
            investor_name = row_content[5]  # 投资方名称
            country = row_content[6]  # 投资方国别
            provence = row_content[7]  # 投资方省份
            city = row_content[8]  # 投资方市
            industry1 = row_content[9]  # 所属行业1
            industry2 = row_content[10]  # 所属行业2
            investment_volume = row_content[11]  # 总投资额(万元)
            construction_content = row_content[12]  # 建设内容
            construction_nature = row_content[13]  # 建设性质（亩）
            project_address = row_content[14]  # 项目选址
            use_land = row_content[15]  # 项目用地情况（亩）
            new_land = row_content[16]  # 其中新增用地（亩）
            set_project_status = row_content[17]  # 项目立项状态
            project_progress = row_content[18]  # 项目进展
            sign_time = row_content[19]  # 签约时间
            start_time = row_content[20]  # 开工时间
            end_time = row_content[21]  # 竣工时间
            is_fixed_investment = row_content[22]  # 固定资产投资项目
            investment_year = row_content[23]  # 资金到位本年累计（万元）
            investment_history = row_content[24]  # 资金到位历史累计（万元）
            project_stalker = row_content[25]  # 项目跟踪
            project_stalker_explain = row_content[26]  # 项目跟踪说明
        except Exception as e:
            # 表示操作失败，回滚数据库操作
            current_app.logger.error(e)
            return jsonify(code=RET.DBERR, msg="数据异常！请尝试 <清空浏览器缓存> 后下载最新模板，根据模板提示信息编辑数据后再次上传。")

        if not project_name:
            return jsonify(code=RET.PARAMERR, msg='项目名称不能为空！')

        project_obj_list = ProjectManagement.query.all()  # 项目编号
        time_strf = datetime.now().strftime("%Y%m%d")
        max_project_num = ''
        if project_obj_list:
            max_project_num = max([project_obj.project_num for project_obj in project_obj_list])
        if max_project_num:
            max_project_num = max_project_num[8:]
            num = get_num(max_project_num)
            if num == 'error':
                # return jsonify(code=RET.DATAERR, msg='编号超出三位的规定范围，请联系管理员')
                return 'error'
            project_num = time_strf + num
        else:
            project_num = time_strf + '001'
        try:
            # 写入数据库
            file_time = datetime.now().strftime("%Y-%m-%d %H:%M")
            project_obj = ProjectManagement(
                project_num=project_num,
                project_name=project_name,
                district=district,
                development_area=development_area,
                attract_name=attract_name,
                investor_name=investor_name,
                country=country,
                provence=provence,
                city=city,
                industry=industry1 + '/' + industry2,
                investment_volume=investment_volume,
                construction_content=construction_content,
                construction_nature=construction_nature,
                project_address=project_address,
                use_land=use_land,
                new_land=new_land,
                set_project_status=set_project_status,
                project_progress=project_progress,
                sign_time=sign_time,
                start_time=start_time,
                end_time=end_time,
                is_fixed_investment=is_fixed_investment,
                investment_year=investment_year,
                investment_history=investment_history,
                project_stalker=project_stalker,
                project_stalker_explain=project_stalker_explain,
                upload_unity=user_unity,
                upload_people=user_name,
                upload_time=file_time,
            )
            db.session.add(project_obj)
            db.session.commit()
            success_num += 1
            continue
        except Exception as e:
            # 表示操作失败，回滚数据库操作
            db.session.rollback()
            current_app.logger.error(e)
            return jsonify(code=RET.DBERR, msg="数据库异常")

    if success_num > 0:
        return jsonify(code=RET.OK,
                       msg='上传成功！数据上传 {} 条数据'.format(success_num))
    else:
        return jsonify(code=RET.DATAERR, msg='无新数据上传。')


# 批量导出---项目信息台账
@api_manage.route("/BatchExportProject5", methods=["POST"])
def batch_export_project5():
    req_dic = request.get_json()
    token = request.headers['token']
    try:
        user_obj = verify_token(token)
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")


    select_id_list = req_dic["select_id_list"]
    path = './apps/statics/project_file/'
    pro_path = 'http://39.100.39.50:5050/aaa_statics/project_file/'  # 项目路径
    # pro_path = 'http://192.168.1.4:5000/statics/project_file/'  # 项目路径
    if not select_id_list:
        return jsonify(code=RET.PARAMERR, msg="参数不能为空！")
    target_data_list = []
    for select_id in select_id_list:
        try:
            project_obj = ProjectManagement.query.filter_by(id=select_id).first()
            # 提取数据，写入xslx表格
            data_list = []
            project_num = project_obj.project_name
            data_list.append(project_num)
            project_name = project_obj.class_project_manager
            data_list.append(project_name)
            district = project_obj.project_executor
            data_list.append(district)
            development_area = project_obj.invest_company
            data_list.append(development_area)
            attract_name = project_obj.investment_volume
            data_list.append(attract_name)
            investor_name = project_obj.project_scale
            data_list.append(investor_name)
            country = project_obj.class_investor_name
            data_list.append(country)
            provence = project_obj.class_investor_mobile
            data_list.append(provence)
            city = project_obj.argument_opinion
            data_list.append(city)
            industry1 = project_obj.project_content
            data_list.append(industry1)
            industry2 = project_obj.project_appeal
            data_list.append(industry2)
            investment_volume = project_obj.project_problem
            data_list.append(investment_volume)
            construction_content = project_obj.project_source
            data_list.append(construction_content)
            construction_nature = project_obj.district
            data_list.append(construction_nature)
            project_address = project_obj.industry
            data_list.append(project_address)
            use_land = project_obj.file_unit
            data_list.append(use_land)
            new_land = project_obj.file_time
            data_list.append(new_land)
            set_project_status = project_obj.file_time
            data_list.append(set_project_status)
            project_progress = project_obj.file_time
            data_list.append(project_progress)
            sign_time = project_obj.file_time
            data_list.append(sign_time)
            start_time = project_obj.file_time
            data_list.append(start_time)
            end_time = project_obj.file_time
            data_list.append(end_time)
            is_fixed_investment = project_obj.file_time
            data_list.append(is_fixed_investment)
            investment_year = project_obj.file_time
            data_list.append(investment_year)
            investment_history = project_obj.file_time
            data_list.append(investment_history)
            project_stalker = project_obj.file_time
            data_list.append(project_stalker)
            project_stalker_explain = project_obj.file_time
            data_list.append(project_stalker_explain)
            target_data_list.append(data_list)
        except Exception as e:
            current_app.logger.error(e)
            return jsonify(code=RET.DBERR, msg="数据库查询错误！")
    head_list = ''
    sheet = ''
    try:
        sheet_name_titles = {
            "sheet1": ["项目编号", "项目名称", "项目所在地", "所属开发区", "引资方名称", "投资方名称",
                       "投资方所在地", "所属行业", "总投资额（万元）", "项目建设内容", "项目建设性质",
                       "项目选址详情", "项目用地情况", "项目立项情况", "项目进展", "签约时间",
                       "开工时间", "竣工时间", "固资产投资项目（是、否）", "资金到位本年累计（万元）",
                       "资金到位历史累计（万元）", "项目跟踪", "项目跟踪说明",
                       "国别（地区）", "省（自治区、直辖市、特别行政区）",
                       "市（州、盟、区）", "用地情况（亩）", "其中新增用地（亩）"
                       ]}

        excel = xlwt.Workbook(encoding='utf-8')
        # 写入表头
        for i in range(len(sheet_name_titles)):
            for k, v in sheet_name_titles.items():
                sheet_name = k
                sheet = excel.add_sheet(sheet_name)
                head_list = v
                print(head_list)
                for j in range(len(head_list)):
                    sheet.write(0, j, head_list[j])
        # 写入数据，从第二行(i+1)
        rows = len(target_data_list)
        cols = len(head_list)
        for i in range(rows):
            for j in range(cols):
                sheet.write(i + 1, j, target_data_list[i][j])
        time_stamp = '{0:%Y%m%d%H%M%S}'.format(datetime.now())
        file_name = "招商引资项目表{}.xlsx".format(time_stamp)
        excel.save(path + file_name)
        return jsonify(code=RET.OK, url=pro_path + file_name, msg="导出/下载成功！")
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.DBERR, msg="批量导出操作失败！")


# def get_project_type(file_type):
#     # 获取项目阶段id，和项目事项阶段id
#     # if int(audit_status) == 8:  # 当状态id为8(通过)并且file_type为 2时是洽谈阶段;9时是签约阶段;14时是开工阶段;17时是投产阶段; 19时是项目终止或结转
#     project_type = ''
#     if int(file_type) == 1:
#         project_type = 2  # 1招引项目，2洽谈项目，3签约项目，4开工项目，5投产项目，6终止
#     elif int(file_type) == 6:
#         project_type = 3
#     elif int(file_type) == 13:
#         project_type = 6
#     return project_type
#
#
# def get_project_type_name(project_type):
#     # '1招引项目，2洽谈项目，3签约项目，4开工项目，'
#     # '5投产项目，6终止项目，7完结项目，8暂缓项目'
#     project_type_name = '招引项目' if project_type == 1 \
#         else '洽谈项目' if project_type == 2 \
#         else '签约项目' if project_type == 3 \
#         else '开工项目' if project_type == 4 \
#         else '投产项目' if project_type == 5 \
#         else '终止项目' if project_type == 6 \
#         else '完结项目' if project_type == 7 \
#         else '暂缓项目' if project_type == 8 \
#         else ''
#     return project_type_name
#
#
# def get_item_name(file_type):
#     file_name = "信息台账" if file_type == 1 \
#         else "《项目投资意向书》" if file_type == 2 \
#         else "《项目立项审批单》" if file_type == 3 \
#         else "项目化台账" if file_type == 4 \
#         else "《重点项目专题报告》" if file_type == 5 \
#         else "项目专班" if file_type == 6 \
#         else "《项目目标管理计划书》" if file_type == 7 \
#         else "深入论证" if file_type == 8 \
#         else "《项目合作协议（初稿）》" if file_type == 9 \
#         else "《项目合作协议（修改稿）》" if file_type == 10 \
#         else "《签约项目协议合法性审查意见》" if file_type == 11 \
#         else "《太原市公平竞争审查表》" if file_type == 12 \
#         else "《项目合作协议（送审稿）》" if file_type == 13 \
#         else "《综合审查》" if file_type == 14 \
#         else "《项目合作协议》" if file_type == 15 \
#         else "综合审批" if file_type == 16 \
#         else "代办手续" if file_type == 17 \
#         else "《完成情况申请验收表》" if file_type == 18 \
#         else "《完成情况验收表》" if file_type == 19 \
#         else "《申请终止(结转)审批表》" if file_type == 20 else ''
#     return file_name
#
#
# # 待办事项的历史记录
# def write_history(file_id, project_id, audit_time, item, status, file_type, user_id, receive_people_id):
#     his_obj = ProjectHistory(project_id=project_id,
#                              user_id=user_id,
#                              receive_people_id=receive_people_id,
#                              file_id=file_id,
#                              time=audit_time,
#                              item=item,
#                              status=status,
#                              file_type=file_type
#                              )
#     db.session.add(his_obj)
#     db.session.commit()
#
#
# # 记录项目动态
# def write_dynamic(user_name, role_id, project_id, user_id, action, file_name, time):
#     dynamic_obj = ProjectDynamicLog(operation_people=user_name,
#                                     operation_people_role=role_id,
#                                     project_id=project_id,
#                                     user_id=user_id,
#                                     action=action,
#                                     operation_content=file_name,
#                                     operation_time=time
#                                     )
#     db.session.add(dynamic_obj)
#     db.session.commit()
#
#
# # 项目日志---上传项目日志相关文件
# def upload_daily_picture(file_name, file):
#     try:
#         access_key_id = "LTAI4Fkgi7DUf6jCVW3KNGwT"
#         access_key_secret = "ynr6TWWNOnpALn3YUICUaXwpp9w4er"
#         auth = oss2.Auth(access_key_id, access_key_secret)
#         bucket_name = "zysf-store"
#         endpoint = "oss-cn-beijing.aliyuncs.com"
#         bucket = oss2.Bucket(auth, endpoint, bucket_name)
#         file_name = file_name.split('.')
#         time_stamp = '{0:%Y%m%d%H%M%S}'.format(datetime.now())
#         file_name = file_name[0] + time_stamp + '.' + file_name[1]
#         bucket.put_object('太原二期项目化管理相关文件/日志附件文件/' + file_name, file)
#         file_url = "https://{}.{}/{}".format(bucket_name, endpoint, '太原二期项目化管理相关文件/日志附件文件/' + file_name)
#         time.sleep(1)
#         return file_url
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.THIRDERR, msg='第三方系统(阿里云oss存储)出错！')
#
#
# def zip_files(filelists, zipfilepath, dir_path):
#     filelists = os.listdir(dir_path)
#     if filelists == None or len(filelists):
#         print(">>>>>>待压缩的文件里面不存在文件,无需压缩. <<<<<")
#     else:
#         zip = zipfile.ZipFile(zipfilepath, 'w', zipfile.ZIP_DEFLATED)
#         for file in filelists:
#             filefullpath = os.path.join(dir_path, file)
#
#             # filefullpath是文件的全路径，fil是文件名，这样就不会带目录啦
#
#             zip.write(filefullpath, file)
#
#             zip.close()
#
#
# # 项目事项---获取已上传事项文件
# @api_manage.route("/GetItemList", methods=["POST"])
# def get_item_list():
#     req_dic = request.get_json()
#     project_id = req_dic['project_id']
#
#     try:
#         # 获取该项目的事项阶段id，判断事项阶段，根据阶段去获取相应文件信息
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         project_class = project_obj.project_class
#         item_stage_id = project_obj.item_stage_id
#         file_people = project_obj.file_people
#         file_people2 = project_obj.file_people2
#         data1 = ''
#         data2 = ''
#         data3 = ''
#         data4 = ''
#         data5 = ''
#         data6 = ''
#         data7 = ''
#         # 如果阶段id大于1就返回信息台账的项目事项信息
#         if item_stage_id >= 4:
#             data1 = {
#                 "file_type": 1,
#                 "item_name": '项目信息台账',
#                 "project_type": 1,
#                 "apply_time": project_obj.file_time,
#                 "deal_time": '---',
#                 "file_audit_status": project_obj.project_audit_status,
#                 "project_id": project_obj.id,
#                 "file_people": file_people,
#                 "status": '已提交',
#                 "status1": '已建档',
#                 "apply_time1": project_obj.file_time,
#                 "file_people1": file_people,
#             }
#
#             data2 = {
#                 "file_type": 4,
#                 "item_name": '项目化台账',
#                 "project_type": 2,
#                 "apply_time": project_obj.file_time2,
#                 "deal_time": '---',
#                 "file_audit_status": project_obj.project_audit_status,
#                 "project_id": project_obj.id,
#                 "file_people": file_people2,
#                 "status": '已提交',
#                 "status1": '已建档',
#                 "apply_time1": project_obj.file_time2,
#                 "file_people1": file_people2,
#             }
#
#         elif item_stage_id >= 1:
#             data1 = {
#                 "file_type": 1,
#                 "item_name": '项目信息台账',
#                 "project_type": 1,
#                 "apply_time": project_obj.file_time,
#                 "deal_time": '---',
#                 "file_audit_status": project_obj.project_audit_status,
#                 "project_id": project_obj.id,
#                 "file_people": file_people,
#                 "status": '已提交',
#                 "status1": '已建档',
#                 "apply_time1": project_obj.file_time,
#                 "file_people1": file_people,
#             }
#
#         if item_stage_id >= 17:
#             if project_obj.is_examine:
#                 data3 = {
#                     "file_type": 14,
#                     "item_name": '《综合审查》',
#                     "apply_time": project_obj.examine_time,
#                     "deal_time": '---',
#                     "file_audit_status": project_obj.project_audit_status,
#                     "project_id": project_obj.id,
#                     "file_people": project_obj.examine_people,
#                     "status": '已提交',
#                     "status1": '已建档',
#                     "apply_time1": project_obj.examine_time,
#                     "file_people1": project_obj.examine_people,
#                 }
#             if project_obj.is_project_examine:
#                 data4 = {
#                     "file_type": 16,
#                     "item_name": '项目综合审批',
#                     "apply_time": project_obj.project_examine_time,
#                     "deal_time": '---',
#                     "file_audit_status": project_obj.project_audit_status,
#                     "project_id": project_obj.id,
#                     "file_people": project_obj.project_examine_people,
#                     "status": '已提交',
#                     "status1": '已建档',
#                     "apply_time1": project_obj.project_examine_time,
#                     "file_people1": project_obj.project_examine_people,
#                 }
#             if project_obj.is_procedure:
#                 data5 = {
#                     "file_type": 17,
#                     "item_name": '项目待办手续',
#                     "apply_time": project_obj.procedure_time,
#                     "deal_time": '---',
#                     "file_audit_status": project_obj.project_audit_status,
#                     "project_id": project_obj.id,
#                     "file_people": project_obj.procedure_people,
#                     "status": '已提交',
#                     "status1": '已建档',
#                     "apply_time1": project_obj.procedure_time,
#                     "file_people1": project_obj.procedure_people,
#                 }
#
#         elif item_stage_id >= 16:
#             if project_obj.is_examine:
#                 data3 = {
#                     "file_type": 14,
#                     "item_name": '《综合审查》',
#                     "apply_time": project_obj.examine_time,
#                     "deal_time": '---',
#                     "file_audit_status": project_obj.project_audit_status,
#                     "project_id": project_obj.id,
#                     "file_people": project_obj.examine_people,
#                     "status": '已提交',
#                     "status1": '已建档',
#                     "apply_time1": project_obj.examine_time,
#                     "file_people1": project_obj.examine_people,
#                 }
#             if project_obj.is_project_examine:
#                 data4 = {
#                     "file_type": 16,
#                     "item_name": '项目综合审批',
#                     "apply_time": project_obj.project_examine_time,
#                     "deal_time": '---',
#                     "file_audit_status": project_obj.project_audit_status,
#                     "project_id": project_obj.id,
#                     "file_people": project_obj.project_examine_people,
#                     "status": '已提交',
#                     "status1": '已建档',
#                     "apply_time1": project_obj.project_examine_time,
#                     "file_people1": project_obj.project_examine_people,
#                 }
#
#         elif item_stage_id >= 14:
#             if project_obj.is_examine:
#                 data3 = {
#                     "file_type": 14,
#                     "item_name": '《综合审查》',
#                     "apply_time": project_obj.examine_time,
#                     "deal_time": '---',
#                     "file_audit_status": project_obj.project_audit_status,
#                     "project_id": project_obj.id,
#                     "file_people": project_obj.examine_people,
#                     "status": '已提交',
#                     "status1": '已建档',
#                     "apply_time1": project_obj.examine_time,
#                     "file_people1": project_obj.examine_people,
#                 }
#
#         if item_stage_id >= 6:
#             if project_class:
#                 data6 = {
#                     "file_type": 6,
#                     "item_name": '项目专班',
#                     "apply_time": project_obj.class_time,
#                     "deal_time": '---',
#                     "file_audit_status": project_obj.project_audit_status,
#                     "project_id": project_obj.id,
#                     "file_people": project_class.class_set_people,
#                     "status": '已提交',
#                     "status1": '已建档',
#                     "apply_time1": project_class.class_time,
#                     "file_people1": project_class.class_set_people,
#                 }
#
#         if item_stage_id >= 5:
#             file_obj = ProjectFile.query.filter_by(project_id=project_id, file_type=5).first()
#             if file_obj or project_obj.project_level == '一般项目':
#                 data7 = {
#                     "file_type": 5,
#                     "item_name": '《重点项目专题报告》',
#                     "apply_time": file_obj.file_upload_time if project_obj.project_level == '重点项目' else '---',
#                     # "deal_time": project_obj.item_stage_finish_time if project_obj.project_level == '重点项目' else '---',
#                     "deal_time": file_obj.file_audit_time if project_obj.project_level == '重点项目' else '---',
#                     "file_audit_status": project_obj.project_audit_status if project_obj.project_level == '重点项目' else '---',
#                     "project_id": project_obj.id,
#                     "file_people": file_obj.user.real_name if project_obj.project_level == '重点项目' else '---',
#                     "status": '一般项目' if project_obj.project_level == '一般项目'
#                     else '审核通过' if file_obj.file_audit_status == 1 \
#                         else '驳回' if file_obj.file_audit_status == 3 else '',
#                     "status1": '一般项目' if project_obj.project_level == '一般项目' else '已建档' if project_obj.project_audit_status == 1 else '---',
#                     "apply_time1": project_obj.item_stage_finish_time if project_obj.project_level == '重点项目' else '---',
#                     "file_people1": file_obj.user.real_name if project_obj.project_level == '重点项目' else '---',
#                 }
#
#         file_obj_list = ProjectFile.query.filter_by(project_id=project_id).all()
#         data = [{
#             "file_type": file_obj.file_type,
#             "item_name": get_item_name(file_obj.file_type),
#             "apply_time": file_obj.file_upload_time,
#             "deal_time": '---' if file_obj.file_type in [7, 8, 11, 12, 15, 18,
#                                                          19] else file_obj.file_audit_time if file_obj.file_audit_time else '',
#             "file_audit_status": project_obj.project_audit_status,
#             "project_id": file_obj.project_id,
#             "file_people": file_obj.user.real_name,
#             "id": file_obj.id,
#             "status": '非论证项目' if file_obj.is_lunzheng == 0 and file_obj.file_type == 8 \
#                 else '已终止（结转）项目' if file_obj.is_zhongzhi == 1 and file_obj.file_type == 20 and file_obj.file_audit_status == 1 \
#                 else '待审核' if file_obj.file_audit_status == 4 \
#                 else '已提交' if file_obj.file_audit_status == 1 and file_obj.file_type in [7, 8, 11, 12, 15, 18, 19] \
#                 else '审核通过' if file_obj.file_audit_status == 1 \
#                 else '暂缓' if file_obj.file_audit_status == 0 \
#                 else '终止' if file_obj.file_audit_status == 2 \
#                 else '驳回' if file_obj.file_audit_status == 3 \
#                 else '',  # 文件审核状态 0暂停，1通过，2终止，3驳回，4待审核
#             "status1": '非论证项目' if file_obj.is_lunzheng == 0 and file_obj.file_type == 8 \
#                 else '已建档' if file_obj.file_audit_status == 1
#             else '未建档',
#             "apply_time1": file_obj.file_upload_time if file_obj.file_type in [7, 8, 11, 12, 15, 18,
#                                                                                19] else file_obj.file_audit_time if file_obj.file_audit_status == 1 else '---',
#             "file_people1": file_obj.user.real_name if file_obj.file_audit_status == 1 else '',
#         } for file_obj in file_obj_list]
#         # 把data按照file_type进行排序
#         sorted(data, key=lambda x: x['file_type'], reverse=True)
#         print(data)
#         if item_stage_id >= 4:
#             if data1:
#                 data.insert(0, data1)
#             if data2:
#                 data.insert(4, data2)
#         elif item_stage_id >= 1:
#             if data1:
#                 data.insert(0, data1)
#
#         if item_stage_id >= 17:
#             if data3:
#                 data.insert(14, data3)
#             if data4:
#                 data.insert(16, data4)
#             if data5:
#                 data.insert(17, data5)
#         elif item_stage_id >= 16:
#             if data3:
#                 data.insert(14, data3)
#             if data4:
#                 data.insert(16, data4)
#         elif item_stage_id >= 14:
#             if data3:
#                 data.insert(14, data3)
#
#         if item_stage_id >= 6:
#             if data6:
#                 data.insert(6, data6)
#         if item_stage_id >= 5:
#             if data7:
#                 data.insert(5, data7)
#
#         return jsonify(code=RET.OK, data=data, msg='数据获取成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.DBERR, msg="查询数据库错误！")
#
#
# # 项目事项---上传项目事项相关文件
# @api_manage.route("/UploadProjectFile", methods=["POST"])
# def upload_build_picture():
#     file_type = request.form['file_type']
#     # 1信息台账，文项-2项目投资意向书，文-3项目立项审批单，4项目化台账，
#     # 文-5重点项目专题报告，6项目专班，文-7项目目标管理计划书， 文项-8深入论证，文-9项目合作协议（初稿），
#     # 文-10项目合作协议（修改稿），文-11签约项目协议合法性审查意见，文-12太原市公平竞争审查表，文-13项目合作协议（送审稿），
#     # 14综合审查，文-15项目合作协议，16综合审批，17代办手续，文-18完成情况申请验收表，文-19完成情况验收表，
#     # 文项-20申请终止(结转)审批表
#     project_id = request.form['project_id']
#     # 上传文件时 有是否的选项的文件
#     is_lunzheng = request.form['is_lunzheng']
#     is_yanshou = request.form['is_yanshou']
#     is_zhongzhi = request.form['is_zhongzhi']
#     # 添加的审核人
#     file_audit_people = request.form['file_audit_people']
#     file_audit_people_id = request.form['file_audit_people_id']
#     upload_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#     file_audit_time = ''
#     token = request.headers['token']
#
#     try:
#         section, user_name, operation_mobile, user_id, role_id, belong_unit = verify_identity(token, '')
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="用户信息校验失败，请重新登陆后尝试！")
#
#     try:
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         if not project_obj:
#             return jsonify(code=RET.NODATA, msg='查询失败！无此项目信息，请核实。')
#
#         # 判断文件的上传权限
#         user_obj = User.query.get(user_id)
#         org_id = user_obj.org_id  # 角色id
#         if not org_id:
#             return jsonify(code=RET.NODATA, msg='账号异常，没有设置角色id，请重新注册账号，或联系管理员！')
#
#         if int(file_type) == 2 and user_id != project_obj.file_people_id:
#             return jsonify(code=RET.ROLEERR, msg='《项目投资意向书》只有信息台账上传人才能上传！')
#         elif int(file_type) in [3, 4] and org_id not in [20, 21, 22]:
#             return jsonify(code=RET.ROLEERR, msg='此文件只有【对接服务组】成员才能上传！')
#         elif int(file_type) in [5, 8, 11, 12, 14] and org_id not in [17, 18, 19]:
#             return jsonify(code=RET.ROLEERR, msg='此文件只有【法务论证组】成员才能上传！')
#         elif int(file_type) in [7, 9, 10, 13, 15, 18, 19]:
#             # 判断专班名称是否已存在
#             class_obj1 = project_obj.project_class
#             if not class_obj1:
#                 return jsonify(code=RET.NODATA, msg="请先建立专班并设置项目执行人！")
#             # 判断当前用户是否是当前专班的执行人
#             if user_id != class_obj1.project_executor_id:
#                 return jsonify(code=RET.ROLEERR,
#                                msg="此文件只有当前项目选定的项目专班执行人 <{}> 才能上传！".format(class_obj1.project_executor.split('-')[0]))
#         else:
#             pass
#
#         if int(file_type) == 8 and int(is_lunzheng) == 0:
#             file_obj = ProjectFile(project_id=project_id, file_type=8, file_url='',
#                                    file_upload_time=upload_time, file_audit_status=1, is_lunzheng=is_lunzheng,
#                                    is_yanshou=is_yanshou, is_zhongzhi=is_zhongzhi, user_id=user_id,
#                                    file_audit_people=file_audit_people, file_audit_people_id=file_audit_people_id,
#                                    project_obj=project_id)
#             db.session.add(file_obj)
#             db.session.commit()
#
#             project_obj.item_stage_id = file_type
#             project_obj.project_audit_status = 1
#             db.session.commit()
#             return jsonify(code=RET.OK, msg='提交成功！')
#
#         project_level = project_obj.project_level  # 项目级别
#         project_name = project_obj.project_name  # 项目名称
#         file_people_id = project_obj.file_people_id  # 填报人id
#         if project_level != '重点项目' and file_type == 5:
#             return jsonify(code=RET.PARAMERR, msg='该项目级别为一般项目，不需要上传《重点项目专题报告》，直接进行项目专班流程。')
#
#         file_name = request.form['file_name']
#         file = request.files['file']
#         access_key_id = "LTAI4Fkgi7DUf6jCVW3KNGwT"
#         access_key_secret = "ynr6TWWNOnpALn3YUICUaXwpp9w4er"
#         auth = oss2.Auth(access_key_id, access_key_secret)
#         bucket_name = "zysf-store"
#         endpoint = "oss-cn-beijing.aliyuncs.com"
#         bucket = oss2.Bucket(auth, endpoint, bucket_name)
#         time_stamp = '{0:%Y%m%d%H%M%S}'.format(datetime.now())
#         file_name = file_name.split('.')[0] + time_stamp + '.' + file_name.split('.')[1]
#         bucket.put_object('太原二期项目化管理相关文件/项目事项文件/' + file_name, file)
#         file_url = "https://{}.{}/{}".format(bucket_name, endpoint, '太原二期项目化管理相关文件/项目事项文件/' + file_name)
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.THIRDERR, msg='第三方系统(阿里云oss存储)出错！')
#
#     try:
#         # 判断项目目前状态
#         # if project_obj.project_audit_status in [0, 2, 3]:  # 0暂停，1通过，2终止，3驳回，4待审核
#         #     return jsonify(code=RET.DATAERR, msg='此项目状态异常，请审核通过后重试！')
#
#         file_obj = ProjectFile.query.filter_by(project_id=project_id, file_type=file_type).first()
#         if int(file_type) == 7:
#             file_audit_time = upload_time
#         if file_obj:
#             file_obj.file_type = file_type
#             file_obj.user_id = user_id  # 上传人，项目事项每个文件的上传人不同，不一定是项目的上传人
#             file_obj.file_url = file_url
#             file_obj.is_lunzheng = is_lunzheng
#             file_obj.is_yanshou = is_yanshou
#             file_obj.is_zhongzhi = is_zhongzhi
#             file_obj.file_upload_time = upload_time
#             file_obj.file_audit_time = file_audit_time
#             file_obj.file_audit_people = file_audit_people
#             file_obj.file_audit_people_id = file_audit_people_id
#             if int(file_type) in [7, 8, 11, 12, 15, 18, 19]:  # 7, 11, 12, 15, 18, 19 无审核功能，默认审核通过
#                 file_obj.file_audit_status = 1
#
#             else:
#                 file_obj.file_audit_status = 4  # 刚上传状态为待审核
#             db.session.commit()
#
#         else:
#             if int(file_type) in [7, 8, 11, 12, 15, 18, 19]:
#                 file_obj = ProjectFile(project_id=project_id, file_type=file_type, file_url=file_url,
#                                        file_upload_time=upload_time, file_audit_status=1, is_lunzheng=is_lunzheng,
#                                        is_yanshou=is_yanshou, is_zhongzhi=is_zhongzhi, user_id=user_id,
#                                        file_audit_people=file_audit_people, file_audit_people_id=file_audit_people_id,
#                                        project_obj=project_id, file_audit_time=file_audit_time)  # 刚上传状态为待审核
#             else:
#                 file_obj = ProjectFile(project_id=project_id, file_type=file_type, file_url=file_url,
#                                        file_upload_time=upload_time, file_audit_status=4, is_lunzheng=is_lunzheng,
#                                        is_yanshou=is_yanshou, is_zhongzhi=is_zhongzhi, user_id=user_id,
#                                        file_audit_people=file_audit_people, file_audit_people_id=file_audit_people_id,
#                                        project_obj=project_id, file_audit_time=file_audit_time)  # 刚上传状态为待审核
#             db.session.add(file_obj)
#             db.session.commit()
#
#         # 7, 8, 11, 12, 15, 18, 19 无审核功能，默认审核通过
#         if int(file_type) in [7, 8, 11, 12, 15, 18, 19]:
#             project_obj.item_stage_id = file_type
#             project_obj.project_audit_status = 1
#             project_obj.item_stage_finish_time = upload_time
#
#             if int(file_type) == 15:
#                 project_obj.project_type = 4
#             if int(file_type) == 19:
#                 project_obj.project_type = 7
#             db.session.commit()
#
#         file_name = get_item_name(int(file_type))
#         # 记录项目动态
#         write_dynamic(user_name, role_id, project_id, user_id, '提交了', file_name, upload_time)
#         # 待办事项的历史记录
#         file_id = file_obj.id
#         item = project_name + file_name + "提交"
#         write_history(file_id, project_id, upload_time, item, '已提交', file_type, user_id, '')
#         return jsonify(code=RET.OK, file_url=file_url, msg='文件上传成功！')
#
#     except Exception as e:
#         current_app.logger.error(e)
#         db.session.rollback()
#         return jsonify(code=RET.DBERR, file_url=file_url, msg='项目化管理文件{}入库失败！'.format(file_type))
#
#
# # 下载模板
# @api_manage.route("/DownloadProjectTemplate", methods=["POST"])
# def download_project_template():
#     req_dic = request.get_json()
#
#     #     token = request.headers['token']
#
#     # action_name = '下载模板'
#     # try:
#     #     section, user_name, operation_mobile, user_id, role_id, belong_unit = verify_identity(token, action_name)
#     # except Exception as e:
#     #     current_app.logger.error(e)
#     #     return jsonify(code=RETSESSIONERRDBERR, msg="进行{}操作时用户信息校验失败，请重新登陆后尝试！".format(action_name))
#     token = request.headers['token']
#
#     # 校验权限，仅限查看
#     permission_list = get_permission_list(token)
#     if 16 in permission_list or 20 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#
#     template_type = req_dic['template_type']
#     if not template_type:
#         return jsonify(code=RET.PARAMERR, msg="参数不能为空！")
#
#     if template_type == 1:  # 信息台账模板标识
#         project_template = "http://39.100.39.50:8009/aaa_statics/project_template/招商引资项目信息台账表.xlsx"
#         return project_template
#
#     if template_type == 2:  # 项目化台账模板标识
#         land_template = "http://39.100.39.50:8009/aaa_statics/project_template/招商引资项目化台账表.xlsx"
#         return land_template
#
#
# # 批量导入---项目信息台账批量导入（读取模板数据，保存到数据库）
# @api_manage.route("/UploadProjectData", methods=["POST"])
# def upload_project_data():
#     # 获取上传的文件
#     token = request.headers['token']
#     action_name = '批量导入'
#
#     # 校验权限，仅限查看
#     permission_list = get_permission_list(token)
#     if 15 in permission_list or 19 in permission_list or 60 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#
#     try:
#         section, user_name, operation_mobile, user_id, role_id, belong_unit = verify_identity(token, action_name)
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="进行{}操作时用户信息校验失败，请重新登陆后尝试！".format(action_name))
#
#     # 类型
#     taizhang_type = request.form['taizhang_type']  # 台账类型 1信息化台账、2项目化台账
#     # 上传的文件
#     file = request.files['file']
#     print(file.filename)  # 打印文件名
#
#     try:
#         f = file.read()  # 文件内容
#         data = xlrd.open_workbook(file_contents=f)
#         table = data.sheets()[0]
#         names = data.sheet_names()  # 返回book中所有工作表的名字
#         status = data.sheet_loaded(names[0])  # 检查sheet1是否导入完毕
#         print(status)
#         nrows = table.nrows  # 获取该sheet中的有效行数
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.THIRDERR, msg="读取文件失败！")
#
#     rep_num = 0
#     rep_project_name_list = []
#     success_num = 0
#     name = ''
#
#     row_list = [table.row_values(i) for i in range(2, nrows)]
#     for i in range(0, len(row_list)):
#         row_content = row_list[i]
#         if not row_content:
#             return jsonify(code=RET.NODATA,
#                            msg="表格内无有效数据！请尝试 <清空浏览器缓存> 后下载最新模板，根据模板提示信息编辑数据后再次上传。(注：第三行为首行有效数据不能为空、第一行和第二行无法读取。)")
#
#         del (row_content[0])
#         if int(taizhang_type) == 1:
#             project_name = row_content[0]  # 项目名称
#             # 判断该项目是否已经存在
#             project_obj = ProjectManagement.query.filter_by(project_name=project_name).first()
#             if project_obj:
#                 rep_num += 1
#                 rep_project_name_list.append(project_name)
#                 continue
#             try:
#                 is_taixin = row_content[1]  # 是否属于太忻经济区(是或否)
#                 invest_company = row_content[4]  # 投资主体
#                 investment_volume = float(row_content[5])  # 协议投资额(万元)
#                 project_scale = row_content[6]  # 项目规模(亩)
#                 project_content = row_content[7]  # 项目内容
#                 argument_opinion = row_content[8]  # 论证意见
#                 project_appeal = row_content[9]  # 项目诉求
#                 project_problem = row_content[10]  # 项目存在的问题以及需要解决的事项
#                 class_investor_name = row_content[11]  # 投资人姓名
#                 class_investor_mobile = row_content[12]  # 投资人联系方式
#                 project_source = row_content[13]  # 项目来源
#                 district = row_content[14]  # 项目归属区域
#                 industry = row_content[15]  # 所属行业
#             except Exception as e:
#                 # 表示操作失败，回滚数据库操作
#                 current_app.logger.error(e)
#                 return jsonify(code=RET.DBERR, msg="数据异常！请尝试 <清空浏览器缓存> 后下载最新模板，根据模板提示信息编辑数据后再次上传。")
#
#             if not all([project_name, is_taixin, invest_company, investment_volume, project_scale,
#                         class_investor_name, class_investor_mobile, project_source, district, industry]):
#                 return jsonify(code=RET.PARAMERR, msg='缺少必填项！目前全部字段都为必填项。')
#         # 导入项目化数据
#         if int(taizhang_type) == 2:
#             project_name = row_content[0]  # 项目名称
#             # 判断该项目是否已经存在
#             project_obj = ProjectManagement.query.filter_by(project_name=project_name).first()
#             if not project_obj:
#                 return jsonify(code=RET.DATAERR, msg='数据不存在，请先上传信息化台账！')
#
#             # 项目化台账只有对接服务组成员才能上传
#             user_obj = User.query.get(user_id)
#             org_id = user_obj.org_id
#             if not org_id:
#                 return jsonify(code=RET.NODATA, msg='账号异常，没有设置角色id，请重新注册账号，或联系管理员！')
#             if org_id not in [20, 21, 22]:
#                 return jsonify(code=RET.ROLEERR, msg='项目化台账只有【对接服务组】成员才能上传！')
#
#             try:
#                 work_target = row_content[1]  # 工作目标
#                 time_limit = row_content[2]  # 完成时限
#                 # class_project_manager = row_content[3]  # 项目经理
#                 project_unit = row_content[4]  # 项目单位
#                 # project_executor = row_content[5]  # 项目执行人
#                 related_district = row_content[6]  # 涉及区县(部门)
#                 project_source = row_content[7]  # 项目来源
#                 project_level = row_content[8]  # 项目级别
#                 construction_type = row_content[9]  # 建设类型
#                 remark = row_content[10]  # 备注
#             except Exception as e:
#                 # 表示操作失败，回滚数据库操作
#                 current_app.logger.error(e)
#                 return jsonify(code=RET.DBERR, msg="数据异常！请尝试 <清空浏览器缓存> 后下载最新模板，根据模板提示信息编辑数据后再次上传。")
#
#             if not all([project_name, time_limit, project_unit,
#                         related_district, project_source, construction_type]):
#                 return jsonify(code=RET.PARAMERR, msg="数据有误，请核实！(提示：除了'备注'都为必填项)")
#
#         try:
#             # 写入数据库
#             file_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#             if int(taizhang_type) == 1:
#                 # 获取信息化台账的上传人所属区域
#                 user_obj = User.query.get(user_id)
#                 file_people_district = user_obj.district_name
#                 name = '招商引资项目信息台账表'
#                 project_obj = ProjectManagement(
#                     file_time=file_time,
#                     project_type=1,
#                     item_stage_id=1,
#                     taizhang_type='信息化台账',
#                     project_name=project_name,
#                     is_taixin=is_taixin,
#                     project_level='待定',
#                     invest_company=invest_company,
#                     investment_volume=investment_volume,
#                     project_scale=project_scale,
#                     project_content=project_content,
#                     argument_opinion=argument_opinion,
#                     project_appeal=project_appeal,
#                     project_problem=project_problem,
#                     class_investor_name=class_investor_name,
#                     class_investor_mobile=class_investor_mobile,
#                     project_source=project_source,
#                     industry=industry,
#                     district=district,
#                     file_people=user_name,
#                     file_unit=belong_unit,
#                     file_people_id=user_id,
#                     project_audit_status=1,
#                     item_stage_finish_time=file_time,
#                     file_people_district=file_people_district
#                 )
#                 db.session.add(project_obj)
#                 db.session.commit()
#
#                 # 记录项目动态
#                 write_dynamic(user_name, role_id, project_obj.id, user_id, '创建了', project_name + '《信息化台账》', file_time)
#                 # 记录历史记录
#                 item = project_obj.project_name + '《信息化台账》'
#                 write_history('', project_obj.id, file_time, item, '已提交', 1, user_id, '')
#                 success_num += 1
#                 continue
#
#             if int(taizhang_type) == 2:
#                 # 判断该项目是否已经存在
#                 project_obj = ProjectManagement.query.filter_by(project_name=project_name).first()
#                 if not project_obj:
#                     return jsonify(code=RET.NODATA, msg='请先上传信息化台账！')
#                 project_obj.file_time2 = file_time
#                 # project_obj.taizhang_type = '项目化台账',
#                 project_obj.project_name = project_name
#                 project_obj.work_target = work_target
#                 project_obj.time_limit = time_limit
#                 project_obj.project_unit = project_unit
#                 project_obj.related_district = related_district
#                 project_obj.project_source = project_source
#                 # 项目化上传人
#                 project_obj.file_people2 = user_name,
#                 project_obj.file_people_id2 = user_id,
#
#                 # project_obj.project_level = project_level
#                 # 记录项目事项节点，项目事项编辑之后，节点进入下一级(即《重点项目专题报告》，但是如果项目级别为一般项目
#                 # 的话那么节点进入 项目专班 相关流程)
#                 if project_obj.project_level == '重点项目':
#                     project_obj.item_stage_id = 4
#                 else:
#                     project_obj.item_stage_id = 5
#
#                 project_obj.construction_type = construction_type
#                 project_obj.remark = remark
#                 project_obj.project_audit_status = 1
#                 project_obj.item_stage_finish_time = file_time
#
#                 db.session.commit()
#
#                 # 记录项目动态
#                 write_dynamic(user_name, role_id, project_obj.id, user_id, '流转为', project_name + '《项目化台账》', file_time)
#                 # 记录历史记录
#                 item = project_obj.project_name + '《项目化台账》'
#                 write_history('', project_obj.id, file_time, item, '已提交', 4, user_id, '')
#                 success_num += 1
#                 continue
#         except Exception as e:
#             # 表示操作失败，回滚数据库操作
#             db.session.rollback()
#             current_app.logger.error(e)
#             return jsonify(code=RET.DBERR, msg="数据库异常")
#
#     if rep_num > 0 and success_num > 0:
#         return jsonify(code=RET.OK,
#                        msg='上传成功！{}数据上传 {} 条数据，重复数据 {} 条，上传失败的重复数据为 {}，请核实！'.format(name, success_num, rep_num,
#                                                                                     rep_project_name_list))
#     if rep_num == 0 and success_num > 0:
#         return jsonify(code=RET.OK,
#                        msg='上传成功！{}数据上传 {} 条数据，无重复数据。'.format(name, success_num))
#     if rep_num > 0 and success_num == 0:
#         return jsonify(code=RET.DATAERR,
#                        msg='操作失败！{}数据上传 {} 条数据，重复数据{} 条。'.format(name, success_num, rep_num))
#     if rep_num == 0 and success_num == 0:
#         return jsonify(code=RET.DATAERR, msg='无数据上传(请尝试 <清空浏览器缓存> 后下载最新模板，根据模板提示信息编辑数据后再次上传。)')
#     else:
#         pass
#
#
# # 搜索项目---台账信息
# @api_manage.route("/SearchProject", methods=["POST"])
# def search_project():
#     req_dic = request.get_json()
#
#     token = request.headers['token']
#
#     taizhang_type = req_dic['taizhang_type']  # 台账类型  1项目信息台账，2项目化台账
#
#     project_name = req_dic['project_name']
#     is_taixin = req_dic['is_taixin']
#     project_level = req_dic['project_level']
#     project_type = req_dic['project_type']  # 项目类型  1招引项目，2洽谈项目，3签约项目，4开工项目，5投产项目，6终止项目，7完结项目，8暂缓项目
#     project_audit_status = req_dic['project_audit_status']
#     page = req_dic['page']
#     per_page = req_dic['per_page']
#
#     action_name = ''
#     try:
#         user_obj = verify_token(token)
#         file_people_district = user_obj.district_name
#         org_id = user_obj.org_id
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")
#
#     try:
#         if taizhang_type == 1 and org_id in [27, 28, 29, 30]:
#             project_obj = ProjectManagement.query.filter(
#                 and_(ProjectManagement.project_name.like('%{}%'.format(project_name)) if project_name else text(''),
#                      ProjectManagement.file_people_district == file_people_district,
#                      ProjectManagement.is_taixin == is_taixin if is_taixin else text(''),
#                      ProjectManagement.project_level == project_level if project_level else text(''),
#                      ProjectManagement.project_audit_status == project_audit_status if project_audit_status else text(
#                          ''),
#                      ProjectManagement.taizhang_type == '信息化台账',
#                      ProjectManagement.project_type == project_type if project_type else text('')))
#
#         elif taizhang_type == 1:
#             project_obj = ProjectManagement.query.filter(
#                 and_(ProjectManagement.project_name.like('%{}%'.format(project_name)) if project_name else text(''),
#                      ProjectManagement.is_taixin == is_taixin if is_taixin else text(''),
#                      ProjectManagement.project_level == project_level if project_level else text(''),
#                      ProjectManagement.project_audit_status == project_audit_status if project_audit_status else text(
#                          ''),
#                      ProjectManagement.taizhang_type == '信息化台账',
#                      ProjectManagement.project_type == project_type if project_type else text('')))
#
#         elif taizhang_type == 2 and org_id in [27, 28, 29, 30]:
#             project_obj = ProjectManagement.query.filter(
#                 and_(ProjectManagement.project_name.like('%{}%'.format(project_name)) if project_name else text(''),
#                      ProjectManagement.is_taixin == is_taixin if is_taixin else text(''),
#                      ProjectManagement.file_people_district == file_people_district,
#                      ProjectManagement.project_level == project_level if project_level else text(''),
#                      ProjectManagement.taizhang_type == '项目化台账',
#                      ProjectManagement.project_type == project_type if project_type else text('')))
#
#         elif taizhang_type == 2:
#             project_obj = ProjectManagement.query.filter(
#                 and_(ProjectManagement.project_name.like('%{}%'.format(project_name)) if project_name else text(''),
#                      ProjectManagement.is_taixin == is_taixin if is_taixin else text(''),
#                      ProjectManagement.project_level == project_level if project_level else text(''),
#                      ProjectManagement.taizhang_type == '项目化台账',
#                      ProjectManagement.project_type == project_type if project_type else text('')))
#         else:
#             pass
#         if not project_obj.all():
#             return jsonify(code=RET.NODATA, msg='没有符合条件的数据！')
#         project_size = project_obj.count()
#
#         project_obj_list = project_obj.order_by(ProjectManagement.file_time.desc()).paginate(page, per_page).items
#         if project_obj_list:
#             if taizhang_type == 1:  # 项目信息台账
#                 data = [{
#                     "id": project_obj.id,
#                     "project_name": project_obj.project_name,
#                     "project_type": project_obj.project_type,
#                     "project_level": project_obj.project_level,
#                     "is_taixin": project_obj.is_taixin,
#                     "project_executor": project_obj.project_executor,
#                     "invest_company": project_obj.invest_company,
#                     "investment_volume": project_obj.investment_volume,
#                     "project_scale": project_obj.project_scale,
#                     "project_source": project_obj.project_source,
#                     "file_unit": project_obj.file_unit,
#                     # "file_time": project_obj.file_time.strftime("%Y-%m-%d, %H:%M:%S"),
#                     "file_time": project_obj.file_time,
#                     "class_project_manager": project_obj.class_project_manager,
#                     "class_investor_name": project_obj.class_investor_name,
#                     "class_investor_mobile": project_obj.class_investor_mobile,
#                 } for project_obj in project_obj_list]
#                 return jsonify(code=RET.OK, data={"data": data, "size": project_size, "msg": "数据获取成功！"})
#
#             if taizhang_type == 2:  # 项目化台账
#                 data = [{
#                     "id": project_obj.id,
#                     "project_name": project_obj.project_name,  # 项目名称
#                     "project_type": project_obj.project_type,  # 项目阶段
#                     "project_level": project_obj.project_level,  # 项目级别
#                     "is_taixin": project_obj.is_taixin,  # 是否属于太忻经济区(是或否)
#                     "work_target": project_obj.work_target,  # 工作目标
#                     "time_limit": project_obj.time_limit,  # 完成时限
#                     "class_project_manager": project_obj.class_project_manager,  # 项目经理
#                     "project_unit": project_obj.project_unit,  # 项目单位
#                     "project_executor": project_obj.project_executor,  # 项目执行人
#                     "related_district": project_obj.related_district,  # 涉及区域
#                     "project_source": project_obj.project_source,  # 项目来源
#                     "construction_type": project_obj.construction_type,  # 建设类型
#                     "file_unit": project_obj.file_unit,  # 填报单位
#                     "file_people": project_obj.file_people,  # 填报人
#                     "file_time": project_obj.file_time,  # 填报时间
#                     "class_investor_mobile": project_obj.class_investor_mobile,
#                 } for project_obj in project_obj_list]
#                 return jsonify(code=RET.OK, data={"data": data, "size": project_size, "msg": "数据获取成功！"})
#         else:
#             return jsonify(code=RET.NODATA, msg="没有符合搜索条件的数据！")
#
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.DBERR, msg="查询数据库错误！")
#
#
# # 信息台账---项目信息页，和编辑页的数据展示接口
# @api_manage.route("/CheckProjectDetail", methods=["POST"])
# def check_project1_detail():
#     req_dic = request.get_json()
#     project_type = req_dic['project_type']  # 1为信息化台账，2为项目化台账
#
#     project_id = req_dic['project_id']
#     token = request.headers['token']
#
#     # 校验权限，仅限查看
#     res = only_see(token)
#     if not res:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#
#     if not project_id:
#         return jsonify(code=RET.PARAMERR, msg="参数不能为空！")
#     try:
#         if project_type == 1:
#             project_obj_list = ProjectManagement.query.filter_by(id=project_id)
#             data = [{"id": project_obj.id,
#                      "project_name": project_obj.project_name,  # 项目名称
#                      "project_executor": project_obj.project_executor,  # 项目执行人
#                      "project_level": project_obj.project_level,  # 项目执行人
#                      "item_stage_id": project_obj.item_stage_id,  # 项目执行人
#                      "invest_company": project_obj.invest_company,  # 投资主体
#                      "investment_volume": project_obj.investment_volume,  # 协议投资额(万元)
#                      "project_scale": project_obj.project_scale,  # 项目规模(亩)
#                      "project_source": project_obj.project_source,  # 项目来源
#                      "argument_opinion": project_obj.argument_opinion,  # 论证意见
#                      "project_content": project_obj.project_content,  # 项目内容
#                      "project_appeal": project_obj.project_appeal,  # 项目诉求
#                      "project_problem": project_obj.project_problem,  # 项目存在的问题以及需要解决的事项
#                      "remark": project_obj.remark,  # 备注
#                      "file_unit": project_obj.file_unit,  # 填报单位
#                      "file_people": project_obj.file_people,  # 填报人
#                      "industry": project_obj.industry,  # 所属行业
#                      "district": project_obj.district,  # 项目归属区域
#                      "file_time": project_obj.file_time,  # 填报时间
#                      "class_project_manager": project_obj.class_project_manager,  # 项目经理
#                      "class_investor_name": project_obj.class_investor_name,  # 投资人姓名
#                      "class_investor_mobile": project_obj.class_investor_mobile,  # 投资人联系方式
#                      } for project_obj in project_obj_list]
#             return jsonify(code=RET.OK, data={"data": data, "msg": "数据获取成功！"})
#         if project_type == 2:
#             project_obj_list = ProjectManagement.query.filter_by(id=project_id)
#             data = [{"id": project_obj.id,
#                      "project_name": project_obj.project_name,  # 项目名称
#                      "project_level": project_obj.project_level,  # 项目级别
#                      "project_executor": project_obj.project_executor,  # 项目执行人
#                      "item_stage_id": project_obj.item_stage_id,  # 项目执行人
#                      "project_source": project_obj.project_source,  # 项目来源
#                      "file_unit": project_obj.file_unit,  # 填报单位
#                      "file_people": project_obj.file_people,  # 填报人
#                      "file_time": project_obj.file_time,  # 填报时间
#                      "project_content": project_obj.project_content,  # 项目内容
#                      "remark": project_obj.remark,  # 备注
#
#                      "project_unit": project_obj.project_unit,  # 项目单位
#                      "time_limit": project_obj.time_limit,  # 完成时限
#                      "related_district": project_obj.related_district,  # 涉及区县
#                      "construction_type": project_obj.construction_type,  # 建设类型
#                      "work_target": project_obj.work_target,  # 工作目标
#                      "peihe_unit_target1": project_obj.peihe_unit_target1,  # 配合单位总体目标
#                      "peihe_unit_target2": project_obj.peihe_unit_target2,  # 配合单位分项目标
#                      "peihe_unit_time_limit": project_obj.peihe_unit_time_limit,  # 配合单位完成时限
#                      "class_project_manager": project_obj.class_project_manager,  # 项目经理
#                      } for project_obj in project_obj_list]
#             return jsonify(code=RET.OK, data={"data": data, "msg": "数据获取成功！"})
#
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.DBERR, msg="操作失败！数据库查询错误")
#
#
# # 信息台账编辑---项目信息编辑
# @api_manage.route("/Project1Edit", methods=["POST"])
# def project1_edit():
#     req_dic = request.get_json()
#     project_id = req_dic['id']
#     project_name = req_dic['project_name']  # 项目名称
#     invest_company = req_dic['invest_company']  # 投资主体
#     investment_volume = req_dic['investment_volume']  # 协议投资额
#     project_scale = req_dic['project_scale']  # 项目规模
#     project_source = req_dic['project_source']  # 项目来源
#     industry = req_dic['industry']  # 所属行业
#     district = req_dic['district']  # 项目归属区域
#     argument_opinion = req_dic['argument_opinion']  # 论证意见
#     project_content = req_dic['project_content']  # 项目内容
#     project_appeal = req_dic['project_appeal']  # 项目诉求
#     project_problem = req_dic['project_problem']  # 项目存在的问题以及需要解决的事项
#     class_investor_name = req_dic['class_investor_name']  # 投资人姓名
#     class_investor_mobile = req_dic['class_investor_mobile']  # 投资人联系方式
#     class_project_manager_id = req_dic['class_project_manager_id']  # 项目经理id
#     class_project_manager = req_dic['class_project_manager']  # 项目经理
#     project_executor = req_dic['project_executor']  # 项目执行人
#     project_executor_id = req_dic['project_executor_id']  # 项目执行人id
#
#     token = request.headers['token']
#
#     # 校验权限，仅限查看
#     permission_list = get_permission_list(token)
#     if 32 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#
#     action_name = '编辑信息台账'
#     try:
#         section, user_name, operation_mobile, user_id, role_id, belong_unit = verify_identity(token, action_name)
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         # 《信息台账》仅限上传人、对接服务组成员、法务论证组成员可编辑
#         # if user_id != project_obj.file_people_id:
#         #     return jsonify(code=RET.ROLEERR, msg="仅上传人【{}】方可编辑！".format(project_obj.file_people))
#         user_obj = User.query.get(user_id)
#         org_id = user_obj.org_id
#         if org_id in [17, 18, 19, 20, 21, 22]:
#             pass
#         elif user_id == project_obj.file_people_id:
#             pass
#         else:
#             return jsonify(code=RET.ROLEERR, msg='《信息台账》仅限上传人、对接服务组成员、法务论证组成员才可编辑!')
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="进行{}操作时用户信息校验失败，请重新登陆后尝试！".format(action_name))
#     if not all([project_id, invest_company, investment_volume, project_scale, project_source,
#                 industry, district, class_investor_name, class_investor_mobile]):
#         return jsonify(code=RET.PARAMERR, msg="参数不能为空！目前全字段都为必填项。")
#     try:
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         project_obj.project_name = project_name
#         project_obj.invest_company = invest_company
#         project_obj.investment_volume = investment_volume
#         project_obj.project_scale = project_scale
#         project_obj.project_source = project_source
#         project_obj.industry = industry
#         project_obj.district = district
#         project_obj.argument_opinion = argument_opinion
#         project_obj.project_content = project_content
#         project_obj.project_appeal = project_appeal
#         project_obj.project_problem = project_problem
#         project_obj.class_investor_name = class_investor_name
#         project_obj.class_investor_mobile = class_investor_mobile
#         project_obj.class_project_manager = class_project_manager
#         project_obj.class_project_manager_id = class_project_manager_id
#         project_obj.project_executor = project_executor
#         project_obj.project_executor_id = project_executor_id
#         db.session.add(project_obj)
#         db.session.commit()
#         # 更新项目专班的项目经理和执行人
#         class_obj = project_obj.project_class
#         if class_obj:
#             class_obj.class_project_manager = class_project_manager
#             class_obj.class_project_manager_id = class_project_manager_id
#             class_obj.project_executor = project_executor
#             class_obj.project_executor_id = project_executor_id
#             db.session.commit()
#         # 记录项目动态
#         edit_time = datetime.now().strftime("%Y-%m-%d %H-%M")
#         write_dynamic(user_name, role_id, project_obj.id, user_id, '编辑了', project_name + '信息台账', edit_time)
#
#         return jsonify(code=RET.OK, msg="信息化台账项目信息修改成功！")
#     except Exception as e:
#         db.session.rollback()
#         current_app.logger.error(e)
#         return jsonify(code=RET.DBERR, msg="查询数据库错误！")
#
#
# # 项目化台账编辑---项目信息编辑
# @api_manage.route("/Project2Edit", methods=["POST"])
# def project2_edit():
#     req_dic = request.get_json()
#     project_id = req_dic['id']
#     project_name = req_dic['project_name']  # 项目名称
#     project_level = req_dic['project_level']  # 项目级别
#     project_executor = req_dic['project_executor']  # 项目执行人
#     project_executor_id = req_dic['project_executor_id']  # 项目执行人id
#     project_source = req_dic['project_source']  # 项目来源
#     project_unit = req_dic['project_unit']  # 项目单位
#     time_limit = req_dic['time_limit']  # 完成时限
#     related_district = req_dic['related_district']  # 涉及区县
#     construction_type = req_dic['construction_type']  # 建设类型
#     work_target = req_dic['work_target']  # 工作目标
#     peihe_unit_target1 = req_dic['peihe_unit_target1']  # 配合单位总体目标
#     peihe_unit_target2 = req_dic['peihe_unit_target2']  # 配合单位分项目标
#     peihe_unit_time_limit = req_dic['peihe_unit_time_limit']  # 配合单位完成时限
#     class_project_manager = req_dic['class_project_manager']  # 项目经理
#     class_project_manager_id = req_dic['class_project_manager_id']  # 项目经理id
#     remark = req_dic['remark']  # 备注
#
#     token = request.headers['token']
#
#     # 校验权限，仅限查看
#     permission_list = get_permission_list(token)
#     if 61 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#
#     action_name = '编辑项目化台账'
#     try:
#         section, user_name, operation_mobile, user_id, role_id, belong_unit = verify_identity(token, action_name)
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         # 《项目化台账》仅限上传人、项目推进组成员可编辑
#         user_obj = User.query.get(user_id)
#         org_id = user_obj.org_id
#         if user_id == project_obj.file_people_id2 or org_id in [23, 24, 25]:
#             pass
#         else:
#             return jsonify(code=RET.ROLEERR, msg="仅上传人【{}】和【项目推进组】成员才能编辑！".format(project_obj.file_people2))
#
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="进行{}操作时用户信息校验失败，请重新登陆后尝试！".format(action_name))
#
#     if not all([project_id, project_name, project_level, project_executor, project_source,
#                 project_unit, time_limit, related_district, construction_type]):
#         return jsonify(code=RET.PARAMERR, msg="请先使用最新项目化模板导入数据(保证数据完整性)，后方可在此编辑！")
#
#     try:
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         project_obj.project_name = project_name
#         project_obj.project_level = project_level
#         project_obj.project_executor = project_executor
#         project_obj.project_executor_id = project_executor_id
#         project_obj.project_source = project_source
#         project_obj.project_unit = project_unit
#         project_obj.time_limit = time_limit
#         project_obj.related_district = related_district
#         project_obj.construction_type = construction_type
#         project_obj.work_target = work_target
#         project_obj.peihe_unit_target1 = peihe_unit_target1
#         project_obj.peihe_unit_target2 = peihe_unit_target2
#         project_obj.peihe_unit_time_limit = peihe_unit_time_limit
#         project_obj.class_project_manager = class_project_manager
#         project_obj.class_project_manager_id = class_project_manager_id
#         project_obj.remark = remark
#
#         db.session.add(project_obj)
#         db.session.commit()
#
#         # 更新项目专班的项目经理和执行人
#         class_obj = project_obj.project_class
#         if class_obj:
#             class_obj.class_project_manager = class_project_manager
#             class_obj.class_project_manager_id = class_project_manager_id
#             class_obj.project_executor = project_executor
#             class_obj.project_executor_id = project_executor_id
#             db.session.commit()
#
#         # 记录项目动态
#         edit_time = datetime.now().strftime("%Y-%m-%d %H-%M")
#         write_dynamic(user_name, role_id, project_obj.id, user_id, '编辑了', project_name + '项目化台账', edit_time)
#
#         return jsonify(code=RET.OK, msg="项目化台账项目信息修改成功！")
#     except Exception as e:
#         db.session.rollback()
#         current_app.logger.error(e)
#         return jsonify(code=RET.DBERR, msg="查询数据库错误！")
#
#
# # 项目专班---信息展示
# @api_manage.route("/ClassProject1Show", methods=["POST"])
# def class_project_show():
#     req_dic = request.get_json()
#     project_id = req_dic['project_id']
#     token = request.headers['token']
#
#     # 校验权限，仅限查看
#     permission_list = get_permission_list(token)
#     if 76 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#     if not project_id:
#         return jsonify(code=RET.PARAMERR, msg="参数不能为空！")
#     try:
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         class_project_manager = project_obj.class_project_manager
#         project_executor = project_obj.project_executor
#         project_class = project_obj.project_class
#         if not project_class:
#             data = [{"id": '',
#                      "class_name": '',  # 项目专班名称
#                      "class_project_manager": class_project_manager,  # 项目经理
#                      "class_lead_department": '',  # 牵头部门
#                      "class_district": '',  # 承接地
#                      "class_industry_department": '',  # 行业主管部门
#                      "class_security_department": '',  # 要素保障部门
#                      "class_security_department_content": '',  # 要素保障部门工作内容
#                      "class_lead_manager": '',  # 领导小组办公室负责人
#                      "class_lead_manager_content": '',  # 领导小组办公室负责人工作内容
#                      "project_executor": project_executor,  # 项目执行人
#                      }]
#             return jsonify(code=RET.OK, data={"data": data, "msg": "项目专班数据获取成功！"})
#
#         data = [{"id": project_class.id,
#                  "class_name": project_class.class_name,  # 项目专班名称
#                  "class_project_manager": project_class.class_project_manager,  # 项目经理
#                  "class_lead_department": project_class.class_lead_department,  # 牵头部门
#                  "class_district": project_class.class_district,  # 承接地
#                  "class_industry_department": project_class.class_industry_department,
#                  "class_security_department": project_class.class_security_department,  # 要素保障部门
#                  "class_security_department_content": project_class.class_security_department_content,  # 要素保障部门工作内容
#                  "class_lead_manager": project_class.class_lead_manager,  # 领导小组办公室负责人
#                  "class_lead_manager_content": project_class.class_lead_manager_content,  # 领导小组办公室负责人工作内容
#                  "project_executor": project_class.project_executor,  # 项目执行人
#                  }]
#         return jsonify(code=RET.OK, data={"data": data, "msg": "项目专班数据获取成功！"})
#
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.DBERR, msg="操作失败！数据库查询错误")
#
#
# # 信息台账---项目专班编辑
# @api_manage.route("/ClassProjectEdit", methods=["POST"])
# def class_project1_edit():
#     req_dic = request.get_json()
#     project_id = req_dic['id']
#     class_name = req_dic['class_name']
#     class_project_manager = req_dic['class_project_manager']
#     class_project_manager_id = req_dic['class_project_manager_id']
#     class_lead_department = req_dic['class_lead_department']
#     class_district = req_dic['class_district']
#     class_industry_department = req_dic['class_industry_department']
#     class_security_department = req_dic['class_security_department']
#     class_security_department_content = req_dic['class_security_department_content']
#     class_lead_manager_content = req_dic['class_lead_manager_content']
#     project_executor = req_dic['project_executor']
#     project_executor_id = req_dic['project_executor_id']
#
#     token = request.headers['token']
#
#     # 判断编辑专班之前是否已经设置了项目执行人
#     project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#     project_executor1 = project_obj.project_executor
#     item_stage_id = project_obj.item_stage_id
#
#     if not project_executor1:
#         return jsonify(code=RET.NODATA, msg="编辑专班之前请先在 <项目化台账> 编辑中设置项目执行人！")
#
#     # 校验权限，仅限查看
#     permission_list = get_permission_list(token)
#     if 75 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#
#     action_name = '编辑项目专班'
#     edit_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#
#     try:
#         section, user_name, operation_mobile, user_id, role_id, belong_unit = verify_identity(token, action_name)
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="进行{}操作时用户信息校验失败，请重新登陆后尝试！".format(action_name))
#
#     # 判断当前用户是否是当前专班的项目经理或者执行人
#     if user_id not in [project_obj.class_project_manager_id, project_obj.project_executor_id]:
#         return jsonify(code=RET.ROLEERR, msg="只能是当前专班的项目经理或者执行人才能编辑！")
#
#     if not project_id:
#         return jsonify(code=RET.PARAMERR, msg="参数不能为空！")
#     try:
#         # 判断专班名称是否已存在
#         class_obj1 = ProjectClass.query.filter_by(class_name=class_name).first()
#         if class_obj1:
#             if item_stage_id <= 6:
#                 project_obj.item_stage_id = 6
#             class_obj1.class_name = class_name
#             class_obj1.class_set_people = user_name
#             class_obj1.class_set_people_id = user_id
#
#             class_obj1.class_time = edit_time
#             class_obj1.class_project_manager = class_project_manager
#             class_obj1.class_project_manager_id = class_project_manager_id
#             class_obj1.class_lead_department = class_lead_department
#             class_obj1.class_district = class_district
#             class_obj1.class_industry_department = class_industry_department
#             class_obj1.class_security_department = class_security_department
#             class_obj1.class_security_department_content = class_security_department_content
#             class_obj1.class_lead_manager_content = class_lead_manager_content
#             class_obj1.project_executor = project_executor
#             class_obj1.project_executor_id = project_executor_id
#             db.session.commit()
#
#             class_id = class_obj1.id
#
#         else:
#             class_obj = ProjectClass(class_name=class_name,
#                                      class_project_manager=class_project_manager,
#                                      class_project_manager_id=class_project_manager_id,
#                                      class_set_people=user_name,
#                                      class_set_people_id=user_id,
#                                      class_time=edit_time,
#                                      class_lead_department=class_lead_department,
#                                      class_district=class_district,
#                                      class_industry_department=class_industry_department,
#                                      class_security_department=class_security_department,
#                                      class_security_department_content=class_security_department_content,
#                                      class_lead_manager_content=class_lead_manager_content,
#                                      project_executor=project_executor,
#                                      project_executor_id=project_executor_id)
#             db.session.add(class_obj)
#             db.session.commit()
#             # 查询出项目专班id
#             class_id = class_obj.id
#             # 编辑专班后的项目事项id流转
#             project_obj.item_stage_id = 6
#
#         # 更新项目表
#         project_obj.project_executor = project_executor
#         project_obj.project_executor_id = project_executor_id
#         project_obj.class_project_manager = class_project_manager
#         project_obj.class_project_manager_id = class_project_manager_id
#         project_obj.class_id = class_id
#         project_obj.class_time = edit_time
#         db.session.commit()
#
#         # 记录项目动态
#         write_dynamic(user_name, role_id, project_obj.id, user_id, '编辑了', '项目专班', edit_time)
#         # 记录历史记录
#         item = project_obj.project_name + '建立专班'
#         write_history('', project_id, edit_time, item, '已提交', 6, user_id, '')
#         return jsonify(code=RET.OK, msg="编辑成功！")
#     except Exception as e:
#         db.session.rollback()
#         current_app.logger.error(e)
#         return jsonify(code=RET.DBERR, msg="查询数据库错误！")
#
#
# # 项目事项---项目相关文件审核页面数据展示（查看按钮）
# @api_manage.route("/CheckProjectFile", methods=["POST"])
# def check_project_file():
#     req_dic = request.get_json()
#     file_type = req_dic['file_type']  # 1项目投资意向书，2项目立项审批单，
#     # 3重点项目专题报告，4项目目标管理计划书，5深入论证，6项目合作协议（初稿），7项目合作协议（修改稿），
#     # 8签约项目协议合法性审查意见， 9太原市公平竞争审查表，10项目合作协议（送审稿），11项目合作协议，
#     # 12完成情况申请验收表，13申请终止(结转)审批表
#     project_id = req_dic['project_id']
#     token = request.headers['token']
#
#     # 校验权限，仅限查看
#     res = only_see(token)
#     if not res:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#     try:
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         if not project_obj:
#             return jsonify(code=RET.DBERR, msg='查询失败！无此项目信息，请核实。')
#         file_unit = project_obj.file_unit
#         file_people = project_obj.file_people
#         # file_time = project_obj.file_time
#         file_obj = ProjectFile.query.filter_by(project_id=project_id, file_type=file_type).first()
#         if project_obj:
#             file_type = file_obj.file_type
#             file_url = file_obj.file_url
#             upload_time = file_obj.file_upload_time
#             file_audit_people = file_obj.file_audit_people
#             file_audit_time = file_obj.file_audit_time
#             file_audit_status = file_obj.file_audit_status
#             file_audit_message = file_obj.file_audit_message
#             file3_url = file_obj.file3_url
#             file3_name = ''
#             if file3_url:
#                 file3_name = file3_url.split('/')[-1]
#             # print(project_obj)
#             data_dic = {
#                 "file_unit": file_unit,  # 填报单位
#                 "file_people": file_obj.user.real_name,  # 填报人/负责人/发起人
#                 "file_time": upload_time,  # 填报时间
#                 "file_type": file_type,  # 文件类型
#                 "upload_time": upload_time,  # 申请时间/上传时间/发起时间
#                 "file_url": file_url,  # 文件url
#                 "file_audit_people": file_audit_people,  # 审核人
#                 "file_audit_time": file_audit_time,  # 审核时间
#                 "file_audit_status": file_audit_status,  # 文件审核结果
#                 "file_audit_message": file_audit_message,  # 文件审核信息
#                 "file3_url": file3_url,  # 重点专题报告批示文件链接
#                 "file3_name": file3_name  # 重点专题报告批示文件名
#             }
#             return jsonify(code=RET.OK, data=data_dic, msg='数据获取成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.DBERR, msg='数据查询错误！'.format(file_type))
#
#
# # 项目事项---重点项目文件审核功能接口，需要上传批示文件
# @api_manage.route("/AuditProjectFile2", methods=["POST"])
# def audit_project_file2():
#     project_id = request.form['project_id']
#     # 文-5重点项目专题报告，6项目专班，文-7项目目标管理计划书， 文项-8深入论证，文-9项目合作协议（初稿），
#     # 文-10项目合作协议（修改稿），文-11签约项目协议合法性审查意见，文-12太原市公平竞争审查表，文-13项目合作协议（送审稿），
#     # 14综合审查，文-15项目合作协议，16综合审批，17代办手续，文-18完成情况申请验收表，文-19完成情况验收表，
#     # 文项-20申请终止(结转)审批表
#     token = request.headers['token']
#     audit_message = request.form['audit_message']
#     # project_level = request.form['project_level']  # 是投资意向书且审核通过时传 重点项目或者一般项目
#     file_name = request.form['file_name']
#     file = request.files['file']
#     audit_status = int(request.form['audit_status'])  # 0暂停，1通过，2终止，3驳回，4待审核
#
#     audit_name = '暂停' if audit_status == 0 \
#         else '通过' if audit_status == 1 \
#         else '终止' if audit_status == 2 \
#         else '驳回' if audit_status == 3 else ''
#
#     try:
#         section, user_name, operation_mobile, user_id, role_id, belong_unit = verify_identity(token, project_id)
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="进行审核项目时用户信息校验失败，请重新登陆后尝试！")
#
#     try:
#         audit_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         if not project_obj:
#             return jsonify(RET.NODATA, msg='查询无此项目！')
#         project_name = project_obj.project_name
#
#         file_obj = ProjectFile.query.filter_by(project_id=project_id, file_type=5).first()
#         if not file_obj:  # 用于文件再次审核时
#             return jsonify(RET.NODATA, msg='还未上传文件！')
#         # 只有上传文件时选择的审核人才能审核
#         file_audit_people_id = file_obj.file_audit_people_id
#         if file_audit_people_id != user_id:
#             return jsonify(code=RET.ROLEERR,
#                            msg="只有上传该文件时选择的审核人 <{}> 才能审核！".format(file_obj.file_audit_people.split('-')[0]))
#
#         # 上传重点项目批示文件
#         file_url3 = upload_daily_picture(file_name, file)
#
#         # 如果审核状态为暂缓时，只更改项目状态，不更改项目类型和事项阶段
#         if audit_status in [0, 2, 3]:
#             project_obj.project_audit_status = audit_status
#             # project_obj.project_level = project_level
#             project_obj.project_audit_message = audit_message
#             project_obj.item_stage_finish_time = audit_time  # 上级事项完成时间
#
#             if audit_status == 0:
#                 project_obj.project_type = 8
#             if audit_status == 2:
#                 project_obj.project_type = 6
#             if audit_status == 3:
#                 project_obj.project_type = 1
#             db.session.commit()
#
#             file_obj.file_audit_message = audit_message
#             file_obj.file_audit_status = audit_status
#             file_obj.file_audit_time = audit_time
#             db.session.commit()
#         # 当文件id为 2, 8, 20 时审核结果是针对项目而言，其他的是针对于项目事项的文件而言
#         else:
#             file_obj = ProjectFile.query.filter_by(project_id=project_id, file_type=5).first()
#             if file_obj:  # 用于文件再次审核时
#                 file_obj.file3_url = file_url3
#                 file_obj.file_type = 5
#                 file_obj.file_audit_people = user_name
#                 file_obj.file_audit_time = audit_time
#                 file_obj.file_audit_status = audit_status
#                 file_obj.file_audit_message = audit_message
#                 db.session.commit()
#
#                 project_obj.item_stage_finish_time = audit_time  # 上级事项完成时间
#                 project_obj.item_stage_id = 5
#                 project_obj.project_audit_status = audit_status
#                 project_obj.project_audit_message = audit_message
#                 db.session.commit()
#
#             else:
#                 return jsonify(RET.NODATA, msg='还未上传事项文件！')
#
#         # 待办事项的历史记录
#         status = '已审核'
#         file_id = file_obj.id
#         item = project_name + "《重点项目专题报告》审核"
#         write_history(file_id, project_id, audit_time, item, status, 5, user_id, '')
#
#         # 记录项目动态
#         write_dynamic(user_name, role_id, project_obj.id, user_id, '审核{}了'.format(audit_name), '《重点项目专题报告》', audit_time)
#         return jsonify(code=RET.OK, msg='审核成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         db.session.rollback()
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目事项---项目相关文件审核功能接口
# @api_manage.route("/AuditProjectFile", methods=["POST"])
# def audit_project_file():
#     req_dic = request.get_json()
#     project_id = req_dic['project_id']
#     file_type = req_dic['file_type']  # 1信息台账，文项-2项目投资意向书，文-3项目立项审批单，4项目化台账，
#     # 文-5重点项目专题报告，6项目专班，文-7项目目标管理计划书， 文项-8深入论证，文-9项目合作协议（初稿），
#     # 文-10项目合作协议（修改稿），文-11签约项目协议合法性审查意见，文-12太原市公平竞争审查表，文-13项目合作协议（送审稿），
#     # 14综合审查，文-15项目合作协议，16综合审批，17代办手续，文-18完成情况申请验收表，文-19完成情况验收表，
#     # 文项-20申请终止(结转)审批表
#     token = request.headers['token']
#
#     try:
#         section, user_name, operation_mobile, user_id, role_id, belong_unit = verify_identity(token, project_id)
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="进行审核项目时用户信息校验失败，请重新登陆后尝试！")
#
#     audit_status = int(req_dic['audit_status'])  # 0暂停，1通过，2终止，3驳回，4待审核
#     audit_name = '暂停' if audit_status == 0 \
#         else '通过' if audit_status == 1 \
#         else '终止' if audit_status == 2 \
#         else '驳回' if audit_status == 3 else ''
#     audit_message = req_dic['audit_message']
#     project_level = req_dic['project_level']  # 是投资意向书且审核通过时传 重点项目或者一般项目
#     try:
#         audit_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         if not project_obj:
#             return jsonify(RET.NODATA, msg='查询无此项目！')
#         project_name = project_obj.project_name
#         file_people_id = project_obj.file_people_id
#
#         file_obj = ProjectFile.query.filter_by(project_id=project_id, file_type=file_type).first()
#         if not file_obj:  # 用于文件再次审核时
#             return jsonify(RET.NODATA, msg='还未上传文件！')
#         # 只有上传文件时选择的审核人才能审核
#         file_audit_people_id = file_obj.file_audit_people_id
#         if file_audit_people_id != user_id:
#             return jsonify(code=RET.ROLEERR,
#                            msg="只有上传该文件时选择的审核人 <{}> 才能审核！".format(file_obj.file_audit_people.split('-')[0]))
#
#         # 如果审核状态为暂缓时，只更改项目状态，不更改项目类型和事项阶段
#         if audit_status in [0, 2, 3]:
#             project_obj.project_audit_status = audit_status
#             project_obj.project_level = project_level
#             project_obj.project_audit_message = audit_message
#             project_obj.item_stage_finish_time = audit_time  # 上级事项完成时间
#
#             if audit_status == 0:
#                 project_obj.project_type = 8
#             if audit_status == 2:
#                 project_obj.project_type = 6
#             if audit_status == 3:
#                 project_obj.project_type = 1
#             db.session.commit()
#
#             file_obj.file_audit_message = audit_message
#             file_obj.file_audit_status = audit_status
#             file_obj.file_audit_time = audit_time
#             db.session.commit()
#         # 当文件id为 2, 8, 20 时审核结果是针对项目而言，其他的是针对于项目事项的文件而言
#         elif int(file_type) in [2, 8, 20]:
#             if int(file_type) == 2 and audit_status == 1:
#                 project_obj.project_audit_status = audit_status
#                 project_obj.project_type = 2  # 如果文件是1项目投资意向书并且审核通过时，项目类型变成2洽谈项目
#                 project_obj.item_stage_finish_time = audit_time  # 上级事项完成时间
#                 project_obj.item_stage_id = file_type  # 项目事项为2投资意向书
#                 project_obj.project_level = project_level
#                 project_obj.project_audit_message = audit_message
#                 db.session.commit()
#
#                 file_obj.file_audit_status = audit_status
#                 file_obj.file_audit_time = audit_time
#                 db.session.commit()
#
#             elif int(file_type) == 20 and audit_status == 1:
#                 project_obj.project_audit_status = audit_status
#
#                 # 审核之前判断项目事项是不是按照顺序走到这里的。
#                 # 如果是（有《完成情况验收表》19的情况），此事项审核通过后项目阶段就是完结项目7；
#                 # 如果不是，此事项审核通过后项目事项阶段就是终止项目6。
#                 file_obj19 = ProjectFile.query.filter_by(project_id=project_id, file_type=19).first()
#                 if not file_obj19:  # 用于文件再次审核时
#                     project_obj.project_type = 6
#                 else:
#                     project_obj.project_type = 7  # 如果文件是14申请终止(结转)审批表并且审核通过时，项目类型变成7完结项目
#                     project_obj.item_stage_id = file_type  # 项目事项为20申请终止(结转)审批表
#                 project_obj.item_stage_finish_time = audit_time  # 上级事项完成时间
#                 project_obj.project_level = project_level
#                 project_obj.project_audit_message = audit_message
#                 db.session.commit()
#
#                 file_obj.file_audit_status = audit_status
#                 file_obj.file_audit_time = audit_time
#                 db.session.commit()
#             else:
#                 project_obj.item_stage_finish_time = audit_time  # 上级事项完成时间
#                 project_obj.project_audit_status = audit_status
#                 project_obj.project_level = project_level
#                 project_obj.project_audit_message = audit_message
#                 project_obj.item_stage_id = file_type
#                 db.session.commit()
#
#                 file_obj.file_audit_status = audit_status
#                 file_obj.file_audit_time = audit_time
#                 db.session.commit()
#         else:
#             file_obj = ProjectFile.query.filter_by(project_id=project_id, file_type=file_type).first()
#             if file_obj:  # 用于文件再次审核时
#                 # 当文件类型是9项目合作协议、19完成情况验收表时需要改变项目类型
#                 # if int(file_type) == 9 and audit_status == 1:  # 当《项目合作协议》15审核完成后才算正式签约---20220708首元
#                 #     project_obj.project_type = 3
#                 if int(file_type) == 19 and audit_status == 1:
#                     project_obj.project_type = 6
#                 if int(file_type) == 9 and audit_status == 1:
#                     project_obj.project_type = 3
#                 file_obj.file_type = file_type
#                 file_obj.file_audit_people = user_name
#                 file_obj.file_audit_time = audit_time
#                 file_obj.file_audit_status = audit_status
#                 file_obj.file_audit_message = audit_message
#                 db.session.commit()
#
#                 project_obj.item_stage_finish_time = audit_time  # 上级事项完成时间
#                 project_obj.item_stage_id = file_type
#                 if file_type == 2:
#                     project_obj.project_level = project_level
#                 project_obj.project_audit_status = audit_status
#                 project_obj.project_audit_message = audit_message
#                 db.session.commit()
#
#             else:  # 用于文件第一次审核时
#                 # 当文件类型是9项目合作协议、19完成情况验收表时需要改变项目类型
#                 if int(file_type) == 9 and audit_status == 1:
#                     project_obj.project_type = 3
#                     project_obj.item_stage_id = file_type
#                     db.session.commit()
#
#                 elif int(file_type) == 19 and audit_status == 1:
#                     project_obj.project_type = 6
#                     project_obj.item_stage_id = file_type
#                     db.session.commit()
#
#                 file_obj = ProjectFile(
#                     project_id=project_id,
#                     file_type=file_type,
#                     file_audit_people=user_name,
#                     file_audit_time=audit_time,
#                     file_audit_status=audit_status,
#                     file_audit_message=audit_message)
#                 db.session.add(file_obj)
#                 db.session.commit()
#
#                 project_obj.item_stage_id = file_type
#                 db.session.commit()
#
#         # 待办事项的历史记录
#         file_name = get_item_name(int(file_type))
#         status = '已审核'
#         file_id = file_obj.id
#         item = project_name + file_name + "审核"
#         write_history(file_id, project_id, audit_time, item, status, file_type, user_id, '')
#
#         # 记录项目动态
#         write_dynamic(user_name, role_id, project_obj.id, user_id, '审核{}了'.format(audit_name), file_name, audit_time)
#
#         return jsonify(code=RET.OK, msg='审核成功！')
#
#     except Exception as e:
#         current_app.logger.error(e)
#         db.session.rollback()
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目事项---《综合审查》/项目综合审批/项目代办手续 编辑、查看接口
# @api_manage.route("/EditThree", methods=["POST"])
# def edit_three():
#     req_dic = request.get_json()
#     is_examine = req_dic['is_examine']
#     is_project_examine = req_dic['is_project_examine']
#     is_procedure = req_dic['is_procedure']
#     project_id = req_dic['project_id']
#
#     flag = req_dic['flag']  # 1是编辑；2是查询
#     file_type = req_dic['file_type']
#     token = request.headers['token']
#     edit_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#
#     try:
#         section, user_name, operation_mobile, user_id, role_id, belong_unit = verify_identity(token, '')
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="用户信息校验失败，请重新登陆后尝试！")
#
#     try:
#         # 判断文件的上传权限
#         user_obj = User.query.get(user_id)
#         org_id = user_obj.org_id  # 角色id
#         if org_id not in [17, 18, 19, 23, 24, 25]:
#             return jsonify(code=RET.ROLEERR, msg='操作失败，请确认事项权限！')
#         # 只有法务论证组才能编辑 综合审查
#         if int(file_type) == 14 and org_id not in [17, 18, 19]:
#             return jsonify(code=RET.ROLEERR, msg='此文件只有【法务论证组】才能上传！')
#         # 只有推进组才能编辑 综合审批 和 待办手续
#         if int(file_type) in [16, 17] and org_id not in [23, 24, 25]:
#             return jsonify(code=RET.ROLEERR, msg='此文件只有【推进组】才能上传！')
#
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         if not project_obj:
#             return jsonify(code=RET.NODATA, msg='查询无此项目！')
#
#         if flag == 1:
#             try:
#                 if int(file_type) == 14:
#                     project_obj.is_examine = is_examine
#                     project_obj.item_stage_id = 14
#                     project_obj.project_type = 4
#                     project_obj.examine_people = user_name
#                     project_obj.examine_people_id = user_id
#                     # if is_examine == 0:
#                     #     project_obj.item_stage_id = 14
#                     # elif is_examine == 1:
#                     #     project_obj.item_stage_id = 15
#                     #     project_obj.project_type = 4
#                     project_obj.project_audit_status = 1
#                     project_obj.examine_time = edit_time
#                     project_obj.taizhang_type = '项目化台账'
#                     db.session.commit()
#                 elif int(file_type) == 16:
#                     project_obj.is_project_examine = is_project_examine
#                     project_obj.item_stage_id = 16
#                     project_obj.project_examine_people = user_name
#                     project_obj.project_examine_people_id = user_id
#                     # if is_project_examine == 0:
#                     #     project_obj.item_stage_id = 16
#                     # elif is_project_examine == 1:
#                     #     project_obj.item_stage_id = 17
#                     project_obj.project_audit_status = 1
#                     project_obj.project_examine_time = edit_time
#                     db.session.commit()
#                 elif int(file_type) == 17:
#                     project_obj.is_procedure = is_procedure
#                     project_obj.item_stage_id = 17
#                     project_obj.project_type = 5
#                     project_obj.procedure_people = user_name
#                     project_obj.procedure_people_id = user_id
#                     # if is_project_examine == 0:
#                     #     project_obj.item_stage_id = 17
#                     # elif is_project_examine == 1:
#                     #     project_obj.item_stage_id = 18
#                     #     project_obj.project_type = 5
#                     project_obj.project_audit_status = 1
#                     project_obj.procedure_time = edit_time
#                     db.session.commit()
#                 else:
#                     return jsonify(code=RET.PARAMERR, msg='参数错误！')
#
#                 # 待办事项的历史记录
#                 status = '已提交'
#                 name = '《综合审查》' if int(file_type) == 14 \
#                     else '项目综合审批' if int(file_type) == 16 \
#                     else '项目代办手续' if int(file_type) == 17 else ''
#
#                 item = project_obj.project_name + name
#                 # file_id = log_obj.id
#                 file_people_id = project_obj.file_people_id
#                 write_history('', project_id, edit_time, item, status, '', user_id, '')
#                 # 记录项目动态
#                 write_dynamic(user_name, role_id, project_id, user_id, '提交了', name, edit_time)
#                 return jsonify(code=RET.OK, msg='编辑成功！')
#             except Exception as e:
#                 current_app.logger.error(e)
#                 db.session.rollback()
#                 return jsonify(code=RET.DBERR, msg='编辑失败！')
#         if flag == 2:
#             status = ''
#             project_name = project_obj.project_name
#             if int(file_type) == 14:
#                 status = project_obj.is_examine
#             elif int(file_type) == 16:
#                 status = project_obj.is_project_examine
#             elif int(file_type) == 17:
#                 status = project_obj.is_procedure
#             data = {'project_name': project_name, 'status': status}
#             return jsonify(code=RET.OK, data=data, msg='查询成功！')
#
#     except Exception as e:
#         current_app.logger.error(e)
#         db.session.rollback()
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目事项---提醒审核
# @api_manage.route("/RemindAudit", methods=["POST"])
# def remind_audit():
#     req_dic = request.get_json()
#     project_id = req_dic['project_id']
#     file_type = req_dic['file_type']  # 文件id  1-20
#     file_id = req_dic['file_id']
#     token = request.headers['token']
#
#     try:
#         section, user_name, operation_mobile, user_id, role_id, belong_unit = verify_identity(token, '')
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="用户信息校验失败，请重新登陆后尝试！")
#
#     try:
#         # 判断是否已经提醒过了
#         remind_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         if not project_obj:
#             return jsonify(RET.NODATA, msg='无此项目，请核实！')
#         project_name = project_obj.project_name
#         file_name = get_item_name(file_type)
#
#         # 查找上传文件时选择的审核人
#         file_obj = ProjectFile.query.filter_by(file_type=file_type, project_id=project_id).first()
#         if not file_obj:
#             return jsonify(code=RET.NODATA, msg="无上传文件！")
#         file_audit_people_id = file_obj.file_audit_people_id
#         # 提醒审核只有上传人才能点击
#         file_upload_people_id = file_obj.user_id
#         file_upload_people = file_obj.user.real_name
#         if file_upload_people_id != user_id:
#             return jsonify(code=RET.ROLEERR, msg="只有文件上传人才能点击提醒审核，此文件上传人为 【{}】！".format(file_upload_people))
#
#         receive_people = file_obj.file_audit_people
#
#         notice_obj = ProjectNoticeLog.query.filter_by(project_id=project_id, user_id=user_id, file_id=file_id,
#                                                       item=project_name + file_name + '审核提醒', file_type=file_type,
#                                                       send_people=user_name, receive_people=receive_people,
#                                                       receive_people_id=file_audit_people_id,
#                                                       send_time=remind_time, is_read=0).first()
#         if notice_obj:
#             return jsonify(code=RET.DBERR, msg='重复提醒！')
#
#         log_obj = ProjectNoticeLog(project_id=project_id, user_id=user_id, file_id=file_id,
#                                    item=project_name + file_name + '审核提醒', file_type=file_type,
#                                    send_people=user_name, receive_people=receive_people,
#                                    receive_people_id=file_audit_people_id,
#                                    send_time=remind_time, is_read=0)
#         db.session.add(log_obj)
#         db.session.commit()
#         return jsonify(code=RET.OK, msg='提醒审核成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         db.session.rollback()
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目日志---编辑项目日报功能接口
# @api_manage.route("/EditDaily", methods=["POST"])
# def edit_daily():
#     req_dic = request.get_json()
#     project_id = req_dic['project_id']
#     day_finished = req_dic['day_finished']
#     day_unfinished = req_dic['day_unfinished']
#     coordinate = req_dic['coordinate']
#     remark = req_dic['remark']
#     token = request.headers['token']
#
#     permission_list = get_permission_list(token)
#
#     # 校验权限，仅限查看
#     if 23 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#
#     try:
#         user_obj = verify_token(token)
#         user_name = user_obj.real_name
#         user_id = user_obj.id
#         role_id = user_obj.role_id
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")
#
#     edit_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#
#     try:
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         if not project_obj:
#             return jsonify(code=RET.NODATA, msg='查询无此项目！')
#         project_name = project_obj.project_name
#         file_people_id = project_obj.file_people_id
#         if not all([project_id, day_finished, day_unfinished, coordinate, remark]):
#             return jsonify(code=RET.PARAMERR, msg='参数不完整！')
#         daily_obj = ProjectDaily(project_id=project_id, day_finished=day_finished, day_unfinished=day_unfinished,
#                                  coordinate=coordinate,
#                                  remark=remark, edit_time=edit_time)
#         db.session.add(daily_obj)
#         db.session.commit()
#
#         daily_id = daily_obj.id
#         # 项目日志历史记录
#         log_type = '日报记录'
#         log_name = '日报更新'
#         log_obj = ProjectDailyLog(daily_id=daily_id, project_id=project_id, log_type=log_type,
#                                   log_time=edit_time, log_name=log_name)
#         db.session.add(log_obj)
#         db.session.commit()
#
#         # 待办事项的历史记录
#         status = '已更新'
#         item = project_name + "日报更新"
#         # file_id = log_obj.id
#         write_history(daily_id, project_id, edit_time, item, status, '', user_id, '')
#         # 记录项目动态
#         write_dynamic(user_name, role_id, project_id, user_id, '提交了', project_name + "日报", edit_time)
#
#         return jsonify(code=RET.OK, msg='日报保存成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         db.session.rollback()
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目日志---编辑项目周报功能接口
# @api_manage.route("/EditWeekly", methods=["POST"])
# def edit_weekly():
#     project_id = request.form['project_id']
#     week_finished = request.form['week_finished']
#     week_unfinished = request.form['week_unfinished']
#     next_plan = request.form['next_plan']
#
#     file = request.files['file']
#     file_name = request.form['file_name']
#     token = request.headers['token']
#
#     permission_list = get_permission_list(token)
#
#     # 校验权限，仅限查看
#     if 24 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#
#     try:
#         user_obj = verify_token(token)
#         user_name = user_obj.real_name
#         user_id = user_obj.id
#         role_id = user_obj.role_id
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")
#
#     edit_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#
#     try:
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         if not project_obj:
#             return jsonify(code=RET.NODATA, msg='查询无此项目！')
#         project_name = project_obj.project_name
#         file_people_id = project_obj.file_people_id
#         if not all([project_id, week_finished, week_unfinished, next_plan, file, file_name]):
#             return jsonify(code=RET.DBERR, msg='参数不完整！')
#
#         file_url = upload_daily_picture(file_name, file)
#         daily_obj = ProjectWeekly(url=file_url, week_finished=week_finished, week_unfinished=week_unfinished,
#                                   next_plan=next_plan, edit_time=edit_time)
#         db.session.add(daily_obj)
#         db.session.commit()
#
#         # 项目日志的历史记录
#         daily_id = daily_obj.id
#         log_type = '周报记录'
#         log_name = '周调度报告'
#         log_obj = ProjectDailyLog(daily_id=daily_id, project_id=project_id, log_type=log_type, log_time=edit_time,
#                                   log_name=log_name)
#         db.session.add(log_obj)
#         db.session.commit()
#
#         # 待办事项历史记录
#         status = '已更新'
#         item = project_name + "周报更新"
#         file_id = log_obj.id
#         write_history(file_id, project_id, edit_time, item, status, '', user_id, '')
#
#         # 记录项目动态
#         write_dynamic(user_name, role_id, project_id, user_id, '提交了', project_name + "周报", edit_time)
#
#         return jsonify(code=RET.OK, msg='周报保存成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         db.session.rollback()
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目日志---编辑项月通报功能接口
# @api_manage.route("/EditMonth", methods=["POST"])
# def edit_month():
#     project_id = request.form['project_id']
#     month_finished = request.form['month_finished']
#     month_sum = request.form['month_sum']
#     next_plan = request.form['next_plan']
#
#     file1 = request.files["file1"]
#     file_name1 = request.form["file_name1"]
#     file2 = request.files["file2"]
#     file_name2 = request.form["file_name2"]
#     token = request.headers['token']
#
#     permission_list = get_permission_list(token)
#
#     # 校验权限，仅限查看
#     if 25 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#
#     try:
#         user_obj = verify_token(token)
#         user_name = user_obj.real_name
#         user_id = user_obj.id
#         role_id = user_obj.role_id
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")
#
#     edit_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#     try:
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         if not project_obj:
#             return jsonify(code=RET.NODATA, msg='查询无此项目！')
#         project_name = project_obj.project_name
#         file_people_id = project_obj.file_people_id
#         file_url1 = ''
#         file_url2 = ''
#         if not all([project_id, month_finished, month_sum, next_plan]):
#             return jsonify(code=RET.DBERR, msg='参数不完整！')
#         if file1 and file_name1:
#             file_url1 = upload_daily_picture(file_name1, file1)
#         if file2 and file_name2:
#             file_url2 = upload_daily_picture(file_name2, file2)
#         daily_obj = ProjectMonth(url1=file_url1, url2=file_url2, project_id=project_id, month_finished=month_finished,
#                                  month_sum=month_sum, next_plan=next_plan, edit_time=edit_time)
#         db.session.add(daily_obj)
#         db.session.commit()
#
#         # 项目日志的历史记录
#         daily_id = daily_obj.id
#         log_type = '月报记录'
#         log_name = '月通报'
#         log_obj = ProjectDailyLog(daily_id=daily_id, project_id=project_id, log_type=log_type, log_time=edit_time,
#                                   log_name=log_name)
#         db.session.add(log_obj)
#         db.session.commit()
#
#         # 待办事项历史记录
#         status = '已更新'
#         item = project_name + "月报更新"
#         file_id = log_obj.id
#         write_history(file_id, project_id, edit_time, item, status, '', user_id, '')
#
#         # 记录项目动态
#         write_dynamic(user_name, role_id, project_id, user_id, '提交了', project_name + "月报", edit_time)
#
#         return jsonify(code=RET.OK, msg='月报保存成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         db.session.rollback()
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目日志---编辑项季观摩报功能接口
# @api_manage.route("/EditQuarter", methods=["POST"])
# def edit_quarter():
#     req_dic = request.get_json()
#
#     project_id = req_dic['project_id']
#     quarter_special = req_dic['quarter_special']
#     problem = req_dic['problem']
#     solution_way = req_dic['solution_way']
#     remark = req_dic['remark']
#     edit_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#     token = request.headers['token']
#
#     permission_list = get_permission_list(token)
#
#     # 校验权限，仅限查看
#     if 26 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#
#     try:
#         user_obj = verify_token(token)
#         user_name = user_obj.real_name
#         user_id = user_obj.id
#         role_id = user_obj.role_id
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")
#
#     try:
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         if not project_obj:
#             return jsonify(code=RET.NODATA, msg='查询无此项目！')
#         project_name = project_obj.project_name
#         file_people_id = project_obj.file_people_id
#
#         daily_obj = ProjectQuarter(project_id=project_id, quarter_special=quarter_special, problem=problem,
#                                    solution_way=solution_way, remark=remark, edit_time=edit_time)
#         db.session.add(daily_obj)
#         db.session.commit()
#
#         # 项目日志的历史记录
#         daily_id = daily_obj.id
#         log_type = '季报记录'
#         log_name = '季观摩'
#         log_obj = ProjectDailyLog(daily_id=daily_id, project_id=project_id, log_type=log_type, log_time=edit_time,
#                                   log_name=log_name)
#         db.session.add(log_obj)
#         db.session.commit()
#
#         # 待办事项历史记录
#         status = '已更新'
#         item = project_name + "季报更新"
#         file_id = log_obj.id
#         write_history(file_id, project_id, edit_time, item, status, '', user_id, '')
#
#         # 记录项目动态
#         write_dynamic(user_name, role_id, project_id, user_id, '提交了', project_name + "季报", edit_time)
#
#         return jsonify(code=RET.OK, msg='季报保存成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         db.session.rollback()
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目日志---编辑项半年晾晒功能接口
# @api_manage.route("/EditHalfYear", methods=["POST"])
# def edit_half_year():
#     req_dic = request.get_json()
#
#     project_id = req_dic['project_id']
#     half_year_finished = req_dic['half_year_finished']
#     half_year_sum = req_dic['half_year_sum']
#     next_plan = req_dic['next_plan']
#     remark = req_dic['remark']
#     edit_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#     token = request.headers['token']
#
#     permission_list = get_permission_list(token)
#
#     # 校验权限，仅限查看
#     if 27 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#
#     try:
#         user_obj = verify_token(token)
#         user_name = user_obj.real_name
#         user_id = user_obj.id
#         role_id = user_obj.role_id
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")
#
#     try:
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         if not project_obj:
#             return jsonify(code=RET.NODATA, msg='查询无此项目！')
#         project_name = project_obj.project_name
#         file_people_id = project_obj.file_people_id
#         daily_obj = ProjectHalfYear(project_id=project_id, half_year_finished=half_year_finished,
#                                     half_year_sum=half_year_sum, next_plan=next_plan, remark=remark,
#                                     edit_time=edit_time)
#         db.session.add(daily_obj)
#         db.session.commit()
#
#         # # 项目日志的历史记录
#         daily_id = daily_obj.id
#         log_type = '半年报记录'
#         log_name = '半年晾晒'
#         log_obj = ProjectDailyLog(daily_id=daily_id, project_id=project_id, log_type=log_type, log_time=edit_time,
#                                   log_name=log_name)
#         db.session.add(log_obj)
#         db.session.commit()
#
#         # 记录待办事项历史记录
#         status = '已更新'
#         item = project_name + "半年报更新"
#         file_id = log_obj.id
#         write_history(file_id, project_id, edit_time, item, status, '', user_id, '')
#
#         # 记录项目动态
#         write_dynamic(user_name, role_id, project_id, user_id, '提交了', project_name + "半年报", edit_time)
#
#         return jsonify(code=RET.OK, msg='半年报记录保存成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         db.session.rollback()
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目日志---编辑项年终总结功能接口
# @api_manage.route("/EditYear", methods=["POST"])
# def edit_year():
#     req_dic = request.get_json()
#
#     project_id = req_dic['project_id']
#     year_finished = req_dic['year_finished']
#     year_sum = req_dic['year_sum']
#     next_plan = req_dic['next_plan']
#     remark = req_dic['remark']
#     edit_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#     token = request.headers['token']
#
#     permission_list = get_permission_list(token)
#
#     # 校验权限，仅限查看
#     if 28 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#
#     try:
#         user_obj = verify_token(token)
#         user_name = user_obj.real_name
#         user_id = user_obj.id
#         role_id = user_obj.role_id
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="进行操作时用户信息校验失败，请重新登陆后尝试！")
#
#     try:
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         if not project_obj:
#             return jsonify(code=RET.NODATA, msg='查询无此项目！')
#         project_name = project_obj.project_name
#         file_people_id = project_obj.file_people_id
#         daily_obj = ProjectYear(project_id=project_id, year_finished=year_finished, year_sum=year_sum,
#                                 next_plan=next_plan, remark=remark, edit_time=edit_time)
#         db.session.add(daily_obj)
#         db.session.commit()
#
#         # 项目日志的历史记录
#         daily_id = daily_obj.id
#         log_type = '年报记录'
#         log_name = '年终总结'
#         log_obj = ProjectDailyLog(daily_id=daily_id, project_id=project_id, log_type=log_type, log_time=edit_time,
#                                   log_name=log_name)
#         db.session.add(log_obj)
#         db.session.commit()
#
#         # 记录待办事项历史记录
#         status = '已更新'
#         item = project_name + "年报更新"
#         file_id = log_obj.id
#         write_history(file_id, project_id, edit_time, item, status, '', user_id, '')
#
#         # 记录项目动态
#         write_dynamic(user_name, role_id, project_id, user_id, '提交了', project_name + "年报", edit_time)
#
#         return jsonify(code=RET.OK, msg='年报保存成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         db.session.rollback()
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目日志---编辑督办通知功能接口
# @api_manage.route("/EditSuperviseNotice", methods=["POST"])
# def edit_supervise():
#     project_id = request.form['project_id']
#     receive_people = request.form['receive_people']
#     receive_people_id = request.form['receive_people_id']
#     finish_time = request.form['finish_time']
#     Supervise_type = request.form['Supervise_type']
#
#     file = request.files['file']
#     file_name = request.form['file_name']
#     token = request.headers['token']
#
#     permission_list = get_permission_list(token)
#
#     # 校验权限，仅限查看
#     if 29 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#     try:
#         section, user_name, operation_mobile, user_id, role_id, belong_unit = verify_identity(token, '')
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="用户信息校验失败，请重新登陆后尝试！")
#
#     edit_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#
#     try:
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         if not project_obj:
#             return jsonify(code=RET.NODATA, msg='查询无此项目！')
#         project_name = project_obj.project_name
#         file_people_id = project_obj.file_people_id
#         if not all([project_id, receive_people, finish_time, Supervise_type, file, file_name]):
#             return jsonify(code=RET.DBERR, msg='参数不完整！')
#
#         file_url = upload_daily_picture(file_name, file)
#         time.sleep(1)
#         daily_obj = ProjectSuperviseNotice(url=file_url, project_id=project_id,
#                                            send_people=user_name,
#                                            send_people_id=user_id,
#                                            receive_people=receive_people,
#                                            receive_people_id=receive_people_id,
#                                            finish_time=finish_time,
#                                            Supervise_type=Supervise_type,
#                                            edit_time=edit_time)
#         db.session.add(daily_obj)
#         db.session.commit()
#
#         # 记录督办通知记录
#         file_id = daily_obj.id
#         notice_obj = ProjectNoticeLog(project_id=project_id,
#                                       user_id=user_id,
#                                       file_id=file_id,
#                                       is_read=0,
#                                       file_type='',
#                                       item=project_name + '督办通知单',
#                                       send_people=user_name,
#                                       receive_people=receive_people,
#                                       receive_people_id=receive_people_id,
#                                       send_time=edit_time)
#         db.session.add(notice_obj)
#         db.session.commit()
#
#         # 项目日志的历史记录
#         daily_id = daily_obj.id
#         log_type = '督办通知单'
#         log_name = '督办通知'
#         log_obj = ProjectDailyLog(daily_id=daily_id, project_id=project_id, log_type=log_type, log_time=edit_time,
#                                   log_name=log_name)
#         db.session.add(log_obj)
#         db.session.commit()
#
#         # 记录待办事项历史记录
#         status = '已更新'
#         item = project_name + "督办通知单更新"
#         file_id = log_obj.id
#         write_history(file_id, project_id, edit_time, item, status, '', user_id, receive_people_id)
#
#         # 记录项目动态
#         write_dynamic(user_name, role_id, project_id, user_id, '提交了', project_name + "督办通知单", edit_time)
#
#         return jsonify(code=RET.OK, msg='督办通知保存成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         db.session.rollback()
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目日志---编辑专项督查报告功能接口
# @api_manage.route("/EditInspectionReport", methods=["POST"])
# def edit_report():
#     project_id = request.form['project_id']
#     receive_people = request.form['receive_people']
#     receive_people_id = request.form['receive_people_id']
#     file = request.files['file']
#     file_name = request.form['file_name']
#     token = request.headers['token']
#
#     permission_list = get_permission_list(token)
#
#     # 校验权限，仅限查看
#     if 30 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#
#     try:
#         section, user_name, operation_mobile, user_id, role_id, belong_unit = verify_identity(token, '')
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="用户信息校验失败，请重新登陆后尝试！")
#
#     edit_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#
#     try:
#         project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#         if not project_obj:
#             return jsonify(code=RET.NODATA, msg='查询无此项目！')
#         project_name = project_obj.project_name
#         file_people_id = project_obj.file_people_id
#         if not all([project_id, receive_people, file_name, file]):
#             return jsonify(code=RET.DBERR, msg='参数不完整！')
#
#         file_url = upload_daily_picture(file_name, file)
#         daily_obj = ProjectInspectionReport(url=file_url, project_id=project_id, receive_people=receive_people,
#                                             receive_people_id=receive_people_id,
#                                             edit_time=edit_time)
#         db.session.add(daily_obj)
#         db.session.commit()
#
#         # 记录督办通知记录
#         file_id = daily_obj.id
#         notice_obj = ProjectNoticeLog(project_id=project_id,
#                                       user_id=user_id,
#                                       file_id=file_id,
#                                       is_read=0,
#                                       item=project_name + '专项督查报告',
#                                       send_people=user_name,
#                                       receive_people=receive_people,
#                                       receive_people_id=receive_people_id,
#                                       send_time=edit_time)
#         db.session.add(notice_obj)
#         db.session.commit()
#
#         # 项目日志的历史记录
#         daily_id = daily_obj.id
#         log_type = '专项督查报告'
#         # log_name = '专项督查报告'
#         log_obj = ProjectDailyLog(daily_id=daily_id, project_id=project_id, log_type=log_type, log_time=edit_time,
#                                   log_name=log_type)
#         db.session.add(log_obj)
#         db.session.commit()
#
#         # 记录待办事项历史记录
#         status = '已更新'
#         item = project_name + "专项督查报告更新"
#         file_id = log_obj.id
#         write_history(file_id, project_id, edit_time, item, status, '', user_id, '')
#
#         # 记录项目动态
#         write_dynamic(user_name, role_id, project_id, user_id, '提交了', project_name + "专项督查报告", edit_time)
#
#         return jsonify(code=RET.OK, msg='专项督查报告保存成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         db.session.rollback()
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目日志---获取日志的历史记录
# @api_manage.route("/GetLogList", methods=["POST"])
# def get_log_list():
#     req_dic = request.get_json()
#
#     project_id = req_dic['project_id']
#     log_type = req_dic['log_type']  # 日志类型
#     time_range = req_dic['time_range']  # 时间范围，整数
#     page = req_dic['page']
#     per_page = req_dic['per_page']
#
#     try:
#         current_time2 = (datetime.now() + relativedelta(days=1)).strftime("%Y-%m-%d 00:00")
#         print(current_time2)
#         if log_type and time_range:
#             current_time1 = (datetime.now() - relativedelta(days=int('{}'.format(time_range)))).strftime(
#                 "%Y-%m-%d 00:00")
#             print(current_time1)
#             log_obj = ProjectDailyLog.query.filter(and_(ProjectDailyLog.project_id == project_id,
#                                                         ProjectDailyLog.log_type == log_type,
#                                                         ProjectDailyLog.log_time > current_time1,
#                                                         ProjectDailyLog.log_time < current_time2))
#             size = log_obj.count()
#         elif log_type:
#             log_obj = ProjectDailyLog.query.filter(ProjectDailyLog.project_id == project_id,
#                                                    ProjectDailyLog.log_type == log_type)
#             size = log_obj.count()
#         elif time_range:
#             current_time1 = (datetime.now() - relativedelta(days=int('{}'.format(time_range)))).strftime(
#                 "%Y-%m-%d 00:00")
#             # current_time2 = datetime.now().strftime("%Y-%m-%d 23:59")
#             log_obj = ProjectDailyLog.query.filter(and_(ProjectDailyLog.project_id == project_id,
#                                                         ProjectDailyLog.log_time > current_time1,
#                                                         ProjectDailyLog.log_time < current_time2))
#             size = log_obj.count()
#         else:
#             log_obj = ProjectDailyLog.query.filter(ProjectDailyLog.project_id == project_id)
#             size = log_obj.count()
#         # 分页
#         log_obj_list = log_obj.order_by(ProjectDailyLog.log_time.desc()).paginate(page, per_page).items
#         log_list = [{
#             "id": log_obj.daily_id,
#             "log_type": log_obj.log_type,
#             "log_time": log_obj.log_time,
#             "log_name": log_obj.log_name
#         } for log_obj in log_obj_list]
#         return jsonify(code=RET.OK, data={"log_list": log_list, "size": size}, msg='查询成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目日志---查看日志详情
# @api_manage.route("/GetLogDetail", methods=["POST"])
# def get_log_detail():
#     req_dic = request.get_json()
#
#     log_id = req_dic['log_id']
#     log_type = req_dic['log_type']  # 日志类型 日报记录； 周报记录； 月报记录； 季报记录； 半年报记录； 年报记录； 督办通知单； 专项督查报告
#     token = request.headers['token']
#     permission_list = get_permission_list(token)
#
#     user_id = verify_token(token).id
#     # 校验权限，仅限查看
#     if 31 in permission_list:
#         pass
#     else:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#     try:
#         data = ''
#         if log_type == '日报记录':
#
#             log_obj = ProjectDaily.query.filter_by(id=log_id).first()
#             if not log_obj:
#                 return jsonify(code=RET.NODATA, msg='无日报记录记录')
#             data = {
#                 "day_finished": log_obj.day_finished,
#                 "day_unfinished": log_obj.day_unfinished,
#                 "coordinate": log_obj.coordinate,
#                 "remark": log_obj.remark,
#                 "edit_time": log_obj.edit_time
#             }
#         elif log_type == '周报记录':
#             log_obj = ProjectWeekly.query.filter_by(id=log_id).first()
#             if not log_obj:
#                 return jsonify(code=RET.NODATA, msg='无周报记录记录')
#             data = {
#                 "week_finished": log_obj.week_finished,
#                 "week_unfinished": log_obj.week_unfinished,
#                 "next_plan": log_obj.next_plan,
#                 "url": log_obj.url,
#                 "edit_time": log_obj.edit_time
#             }
#         elif log_type == '月报记录':
#             log_obj = ProjectMonth.query.filter_by(id=log_id).first()
#             if not log_obj:
#                 return jsonify(code=RET.NODATA, msg='无月报记录记录')
#             data = {
#                 "month_finished": log_obj.month_finished,
#                 "month_sum": log_obj.month_sum,
#                 "next_plan": log_obj.next_plan,
#                 "url1": log_obj.url1,
#                 "url2": log_obj.url2,
#                 "edit_time": log_obj.edit_time
#             }
#         elif log_type == '季报记录':
#             log_obj = ProjectQuarter.query.filter_by(id=log_id).first()
#             if not log_obj:
#                 return jsonify(code=RET.NODATA, msg='无季报记录记录')
#             data = {
#                 "quarter_special": log_obj.quarter_special,
#                 "problem": log_obj.problem,
#                 "solution_way": log_obj.solution_way,
#                 "remark": log_obj.remark,
#                 "edit_time": log_obj.edit_time
#             }
#         elif log_type == '半年报记录':
#             log_obj = ProjectHalfYear.query.filter_by(id=log_id).first()
#             if not log_obj:
#                 return jsonify(code=RET.NODATA, msg='无半年报记录记录')
#             data = {
#                 "half_year_finished": log_obj.half_year_finished,
#                 "half_year_sum": log_obj.half_year_sum,
#                 "next_plan": log_obj.next_plan,
#                 "remark": log_obj.remark,
#                 "edit_time": log_obj.edit_time,
#             }
#         elif log_type == '年报记录':
#             log_obj = ProjectYear.query.filter_by(id=log_id).first()
#
#             if not log_obj:
#                 return jsonify(code=RET.NODATA, msg='无年报记录')
#             data = {
#                 "year_finished": log_obj.year_finished,
#                 "year_sum": log_obj.year_sum,
#                 "next_plan": log_obj.next_plan,
#                 "remark": log_obj.remark,
#                 "edit_time": log_obj.edit_time,
#             }
#         elif log_type == '督办通知单':
#             log_obj = ProjectSuperviseNotice.query.filter_by(id=log_id).first()
#             if not log_obj:
#                 return jsonify(code=RET.NODATA, msg='无督办通知单记录')
#             project_id = log_obj.project_id
#             project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#             if not project_obj:
#                 return jsonify(code=RET.NODATA, msg='查询无此项目！')
#             project_name = project_obj.project_name
#             file_people = project_obj.file_people
#             data = {
#                 "project_name": project_name,
#                 "file_people": log_obj.send_people,
#                 "receive_people": log_obj.receive_people,
#                 "finish_time": (log_obj.finish_time).strftime('%Y-%m-%d'),
#                 "Supervise_type": log_obj.Supervise_type,
#                 "url": log_obj.url,
#                 "edit_time": log_obj.edit_time
#             }
#             read_time = datetime.now().strftime("%Y-%m-%d %H:%M")
#
#             # 设置已读状态
#             notice_obj = ProjectNoticeLog.query.filter_by(file_id=log_id).first()
#             notice_obj.is_read = 1
#             user_id = notice_obj.user_id
#             receive_people_id = notice_obj.receive_people_id
#             db.session.commit()
#
#             # 保存至历史记录
#             his_obj = ProjectHistory(project_id=project_id, user_id=user_id, receive_people_id=receive_people_id,
#                                      file_id=log_id, time=read_time, item=project_name + '督办通知单', status='已读',
#                                      file_type='')
#             db.session.add(his_obj)
#             db.session.commit()
#         elif log_type == '专项督查报告':
#             log_obj = ProjectInspectionReport.query.filter_by(id=log_id).first()
#             if not log_obj:
#                 return jsonify(code=RET.NODATA, msg='无督查报告记录')
#             project_id = log_obj.project_id
#             project_obj = ProjectManagement.query.filter_by(id=project_id).first()
#             if not project_obj:
#                 return jsonify(code=RET.NODATA, msg='查询无此项目！')
#             project_name = project_obj.project_name
#             data = {
#                 "project_name": project_name,
#                 "receive_people": log_obj.receive_people,
#                 "url": log_obj.url,
#                 "edit_time": log_obj.edit_time
#             }
#         return jsonify(code=RET.OK, data=data, msg='数据查询成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目详情---获取项目动态
# @api_manage.route("/GetDynamicLog", methods=["POST"])
# def get_dynamic_detail():
#     req_dic = request.get_json()
#
#     token = request.headers['token']
#
#     project_id = req_dic['project_id']
#     page = req_dic['page']
#     per_page = req_dic['per_page']
#     action_name = '获取项目动态'
#     try:
#         section, user_name, operation_mobile, user_id, role_id, belong_unit = verify_identity(token, action_name)
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.SESSIONERR, msg="进行{}操作时用户信息校验失败，请重新登陆后尝试！".format(action_name))
#
#     try:
#         dynamic_obj = ProjectDynamicLog.query.filter(ProjectDynamicLog.project_id == project_id)
#         if not dynamic_obj.all():
#             return jsonify(code=RET.NODATA, msg='无数据！')
#
#         size = dynamic_obj.count()
#         dynamic_obj_list = dynamic_obj.order_by(ProjectDynamicLog.operation_time.desc()).paginate(page, per_page).items
#
#         data = [{
#             "operation_people":
#                 dynamic_obj.operation_people +
#                 dynamic_obj.action + dynamic_obj.operation_content,
#             "operation_time": (dynamic_obj.operation_time).strftime("%Y-%m-%d %H:%M"),
#         } for dynamic_obj in dynamic_obj_list]
#         return jsonify(code=RET.OK, data={"data": data, "size": size}, msg='数据查询成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.DBERR, msg='数据查询错误！')
#
#
# # 项目档案---下载
# @api_manage.route("/ItemDownload", methods=["POST"])
# def item_download():
#     req_dic = request.get_json()
#     project_id = req_dic['project_id']
#     item_stage_id = req_dic['item_stage_id']  # 1信息台账，文项-2项目投资意向书，
#     token = request.headers['token']
#
#     # 校验权限
#     res = only_see(token)
#     if not res:
#         return jsonify(code=RET.ROLEERR, msg="暂无权限，请联系管理员！")
#
#     if item_stage_id:
#         file_obj = ProjectFile.query.filter_by(project_id=project_id, file_type=item_stage_id).first()
#         if not file_obj:
#             return jsonify(code=RET.NODATA, msg='无符合条件的文件数据！')
#         url = file_obj.file_url
#         if url:
#             return jsonify(code=RET.OK, data=url, msg='文件获取成功！')
#         else:
#             return jsonify(code=RET.NODATA, msg='无文件数据！')
#
#     file_obj_list = ProjectFile.query.filter_by(project_id=project_id).all()
#     if not file_obj_list:
#         return jsonify(code=RET.NODATA, msg='无符合条件的文件数据！')
#     file_list1 = []
#
#     # 获取文件url
#     time_stamp = '{0:%Y%m%d%H%M%S}'.format(datetime.now())  # 时间戳作为将要压缩的文件夹名
#     zip_file = '{}.zip'.format(time_stamp)  # 压缩包名字
#     startdir = "apps/statics/project_items_file/"  # 压缩包根目录
#     file_news = "apps/statics/project_items_file/" + zip_file  # 压缩包路径
#     # 创建新文件夹原来保存下载的文件
#     # 下载文件到事项目录
#     file_list = [file_obj.file_url for file_obj in file_obj_list]
#     for url in file_list:
#         if url:
#             re = requests.get(url)
#             file_name = url.split('事项文件/')[1]
#             with open('apps/statics/project_items_file/' + file_name, "wb") as f:
#                 f.write(re.content)
#                 f.close()
#             file_list1.append('apps/statics/project_items_file/' + file_name)
#
#     zip_files(file_list1, file_news)
#     zip_file1 = 'http:/39.100.39.50:5051/statics/project_items_file/' + zip_file  # 压缩包名字
#     return jsonify(code=RET.OK, data=zip_file1, msg='文件获取成功！')
#
#
# # 根据专班名称获取专班信息
# @api_manage.route("/GetClassInfo", methods=["POST"])
# def class_info():
#     req_dic = request.get_json()
#     class_name = req_dic['class_name']
#     try:
#         class_obj = ProjectClass.query.filter_by(class_name=class_name).first()
#         class_info = {
#             "class_id": class_obj.id,
#             "class_name": class_obj.class_name,
#             "class_project_manager": class_obj.class_project_manager,
#             "project_executor": class_obj.project_executor,
#             "class_lead_department": class_obj.class_lead_department,
#             "class_district": class_obj.class_district,
#             "class_industry_department": class_obj.class_industry_department,
#             "class_security_department": class_obj.class_security_department,
#             "class_security_department_content": class_obj.class_security_department_content,
#             # "class_lead_manager": class_obj.class_lead_manager,
#             "class_lead_manager_content": class_obj.class_lead_manager_content
#         }
#         return jsonify(code=RET.OK, data=class_info, msg='获取成功！')
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.DBERR, msg='获取失败！')
#
#
# # 根据项目判断当前用户是否为此项目执行人
# @api_manage.route("/IsProjectExecutor", methods=["POST"])
# def project_executor():
#     req_dic = request.get_json()
#     project_id = req_dic['project_id']
#     token = request.headers['token']
#     try:
#         user_obj = verify_token(token)
#         user_id = user_obj.id
#     except:
#         return jsonify(code=RET.SESSIONERR, msg='用户信息校验失败，请尝试重新登录！')
#
#     try:
#         project_obj = ProjectManagement.query.get(project_id)
#         project_executor_id = project_obj.project_executor_id
#         if user_id == project_executor_id:
#             return jsonify(code=RET.OK, flag=1, msg='我是此项目的执行人！')
#         else:
#             return jsonify(code=RET.DBERR, flag=0, msg='我并不是此项目的执行人！')
#     except Exception as e:
#         current_app.logger.error(e)
#         return jsonify(code=RET.DBERR, msg='获取失败！')
